from configuration import *

file_name = 'PdfWithAnnotations.pdf'
uploadFile(file_name)

attachment_file = '4pages.pdf'
uploadFile(attachment_file)

page_number = 1

annotation = asposepdfcloud.models.StampAnnotation()
annotation.name = 'Test Name'
annotation.rect = asposepdfcloud.models.Rectangle(
    llx=100, lly=100, urx=200, ury=200)
annotation.flags = [asposepdfcloud.models.AnnotationFlags.DEFAULT]
annotation.horizontal_alignment = asposepdfcloud.models.HorizontalAlignment.CENTER
annotation.rich_text = 'Rich Text'
annotation.subject = 'Subj'
annotation.z_index = 1
annotation.title = 'Title'
annotation.modified = '01/01/2018 12:00:00.000 AM'
annotation.file_path = temp_folder + '/' + attachment_file

response = pdf_api.post_page_stamp_annotations(
    file_name, page_number, [annotation], folder=temp_folder)

pprint(response)


# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from pprint import pformat
from six import iteritems
import re


class GraphInfo(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'line_width': 'float',
        'color': 'Color',
        'dash_array': 'list[int]',
        'dash_phase': 'int',
        'fill_color': 'Color',
        'is_doubled': 'bool',
        'skew_angle_x': 'float',
        'skew_angle_y': 'float',
        'scaling_rate_x': 'float',
        'scaling_rate_y': 'float',
        'rotation_angle': 'float'
    }

    attribute_map = {
        'line_width': 'LineWidth',
        'color': 'Color',
        'dash_array': 'DashArray',
        'dash_phase': 'DashPhase',
        'fill_color': 'FillColor',
        'is_doubled': 'IsDoubled',
        'skew_angle_x': 'SkewAngleX',
        'skew_angle_y': 'SkewAngleY',
        'scaling_rate_x': 'ScalingRateX',
        'scaling_rate_y': 'ScalingRateY',
        'rotation_angle': 'RotationAngle'
    }

    def __init__(self, line_width=None, color=None, dash_array=None, dash_phase=None, fill_color=None, is_doubled=None, skew_angle_x=None, skew_angle_y=None, scaling_rate_x=None, scaling_rate_y=None, rotation_angle=None):
        """
        GraphInfo - a model defined in Swagger
        """

        self._line_width = None
        self._color = None
        self._dash_array = None
        self._dash_phase = None
        self._fill_color = None
        self._is_doubled = None
        self._skew_angle_x = None
        self._skew_angle_y = None
        self._scaling_rate_x = None
        self._scaling_rate_y = None
        self._rotation_angle = None

        if line_width is not None:
          self.line_width = line_width
        if color is not None:
          self.color = color
        if dash_array is not None:
          self.dash_array = dash_array
        if dash_phase is not None:
          self.dash_phase = dash_phase
        if fill_color is not None:
          self.fill_color = fill_color
        if is_doubled is not None:
          self.is_doubled = is_doubled
        if skew_angle_x is not None:
          self.skew_angle_x = skew_angle_x
        if skew_angle_y is not None:
          self.skew_angle_y = skew_angle_y
        if scaling_rate_x is not None:
          self.scaling_rate_x = scaling_rate_x
        if scaling_rate_y is not None:
          self.scaling_rate_y = scaling_rate_y
        if rotation_angle is not None:
          self.rotation_angle = rotation_angle

    @property
    def line_width(self):
        """
        Gets the line_width of this GraphInfo.
        Gets or sets a float value that indicates the line width of the graph.

        :return: The line_width of this GraphInfo.
        :rtype: float
        """
        return self._line_width

    @line_width.setter
    def line_width(self, line_width):
        """
        Sets the line_width of this GraphInfo.
        Gets or sets a float value that indicates the line width of the graph.

        :param line_width: The line_width of this GraphInfo.
        :type: float
        """

        self._line_width = line_width

    @property
    def color(self):
        """
        Gets the color of this GraphInfo.
        Gets or sets a Color object that indicates the color of the graph.

        :return: The color of this GraphInfo.
        :rtype: Color
        """
        return self._color

    @color.setter
    def color(self, color):
        """
        Sets the color of this GraphInfo.
        Gets or sets a Color object that indicates the color of the graph.

        :param color: The color of this GraphInfo.
        :type: Color
        """

        self._color = color

    @property
    def dash_array(self):
        """
        Gets the dash_array of this GraphInfo.
        Gets or sets a dash array.

        :return: The dash_array of this GraphInfo.
        :rtype: list[int]
        """
        return self._dash_array

    @dash_array.setter
    def dash_array(self, dash_array):
        """
        Sets the dash_array of this GraphInfo.
        Gets or sets a dash array.

        :param dash_array: The dash_array of this GraphInfo.
        :type: list[int]
        """

        self._dash_array = dash_array

    @property
    def dash_phase(self):
        """
        Gets the dash_phase of this GraphInfo.
        Gets or sets a dash phase.

        :return: The dash_phase of this GraphInfo.
        :rtype: int
        """
        return self._dash_phase

    @dash_phase.setter
    def dash_phase(self, dash_phase):
        """
        Sets the dash_phase of this GraphInfo.
        Gets or sets a dash phase.

        :param dash_phase: The dash_phase of this GraphInfo.
        :type: int
        """

        self._dash_phase = dash_phase

    @property
    def fill_color(self):
        """
        Gets the fill_color of this GraphInfo.
        Gets or sets a Color object that indicates the fill color of the graph.

        :return: The fill_color of this GraphInfo.
        :rtype: Color
        """
        return self._fill_color

    @fill_color.setter
    def fill_color(self, fill_color):
        """
        Sets the fill_color of this GraphInfo.
        Gets or sets a Color object that indicates the fill color of the graph.

        :param fill_color: The fill_color of this GraphInfo.
        :type: Color
        """

        self._fill_color = fill_color

    @property
    def is_doubled(self):
        """
        Gets the is_doubled of this GraphInfo.
        Gets or sets is border doubled.

        :return: The is_doubled of this GraphInfo.
        :rtype: bool
        """
        return self._is_doubled

    @is_doubled.setter
    def is_doubled(self, is_doubled):
        """
        Sets the is_doubled of this GraphInfo.
        Gets or sets is border doubled.

        :param is_doubled: The is_doubled of this GraphInfo.
        :type: bool
        """

        self._is_doubled = is_doubled

    @property
    def skew_angle_x(self):
        """
        Gets the skew_angle_x of this GraphInfo.
        Gets or sets a float value that indicates the skew angle of the x-coordinate when transforming a coordinate system.

        :return: The skew_angle_x of this GraphInfo.
        :rtype: float
        """
        return self._skew_angle_x

    @skew_angle_x.setter
    def skew_angle_x(self, skew_angle_x):
        """
        Sets the skew_angle_x of this GraphInfo.
        Gets or sets a float value that indicates the skew angle of the x-coordinate when transforming a coordinate system.

        :param skew_angle_x: The skew_angle_x of this GraphInfo.
        :type: float
        """

        self._skew_angle_x = skew_angle_x

    @property
    def skew_angle_y(self):
        """
        Gets the skew_angle_y of this GraphInfo.
        Gets or sets a float value that indicates the skew angle of the y-coordinate when transforming a coordinate system.

        :return: The skew_angle_y of this GraphInfo.
        :rtype: float
        """
        return self._skew_angle_y

    @skew_angle_y.setter
    def skew_angle_y(self, skew_angle_y):
        """
        Sets the skew_angle_y of this GraphInfo.
        Gets or sets a float value that indicates the skew angle of the y-coordinate when transforming a coordinate system.

        :param skew_angle_y: The skew_angle_y of this GraphInfo.
        :type: float
        """

        self._skew_angle_y = skew_angle_y

    @property
    def scaling_rate_x(self):
        """
        Gets the scaling_rate_x of this GraphInfo.
        Gets or sets a float value that indicates the scaling rate of the x-coordinate when transforming a coordinate system.

        :return: The scaling_rate_x of this GraphInfo.
        :rtype: float
        """
        return self._scaling_rate_x

    @scaling_rate_x.setter
    def scaling_rate_x(self, scaling_rate_x):
        """
        Sets the scaling_rate_x of this GraphInfo.
        Gets or sets a float value that indicates the scaling rate of the x-coordinate when transforming a coordinate system.

        :param scaling_rate_x: The scaling_rate_x of this GraphInfo.
        :type: float
        """

        self._scaling_rate_x = scaling_rate_x

    @property
    def scaling_rate_y(self):
        """
        Gets the scaling_rate_y of this GraphInfo.
        Gets or sets a float value that indicates the scaling rate of the y-coordinate when transforming a coordinate system.

        :return: The scaling_rate_y of this GraphInfo.
        :rtype: float
        """
        return self._scaling_rate_y

    @scaling_rate_y.setter
    def scaling_rate_y(self, scaling_rate_y):
        """
        Sets the scaling_rate_y of this GraphInfo.
        Gets or sets a float value that indicates the scaling rate of the y-coordinate when transforming a coordinate system.

        :param scaling_rate_y: The scaling_rate_y of this GraphInfo.
        :type: float
        """

        self._scaling_rate_y = scaling_rate_y

    @property
    def rotation_angle(self):
        """
        Gets the rotation_angle of this GraphInfo.
        Gets or sets a float value that indicates the rotation angle of the coordinate system  when transforming a coordinate system.

        :return: The rotation_angle of this GraphInfo.
        :rtype: float
        """
        return self._rotation_angle

    @rotation_angle.setter
    def rotation_angle(self, rotation_angle):
        """
        Sets the rotation_angle of this GraphInfo.
        Gets or sets a float value that indicates the rotation angle of the coordinate system  when transforming a coordinate system.

        :param rotation_angle: The rotation_angle of this GraphInfo.
        :type: float
        """

        self._rotation_angle = rotation_angle

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, GraphInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from configuration import *
file_name = 'PdfWithAnnotations.pdf'
uploadFile(file_name)

annotation = asposepdfcloud.models.TextAnnotation()
annotation.name = 'Test Free Text'
annotation.rect = asposepdfcloud.models.Rectangle(
    llx=100, lly=100, urx=200, ury=200)
annotation.flags = [asposepdfcloud.models.AnnotationFlags.DEFAULT]
annotation.horizontal_alignment = asposepdfcloud.models.HorizontalAlignment.CENTER
annotation.rich_text = 'Rich Text'
annotation.subject = 'Text Box Subj'
annotation.z_index = 1
annotation.title = 'Title'
annotation.state = asposepdfcloud.models.AnnotationState.UNDEFINED

response_annotations = pdf_api.get_document_text_annotations(
    file_name, folder=temp_folder)
annotation_id = response_annotations.annotations.list[0].id

response = pdf_api.put_text_annotation(
    file_name, annotation_id, annotation, folder=temp_folder)

pprint(response)



from configuration import *

file_name = 'PdfWithAnnotations.pdf'
uploadFile(file_name)

page_number = 1

annotation = asposepdfcloud.models.CircleAnnotation()
annotation.name = 'Test Name'
annotation.rect = asposepdfcloud.models.Rectangle(
    llx=100, lly=100, urx=200, ury=200)
annotation.flags = [asposepdfcloud.models.AnnotationFlags.DEFAULT]
annotation.horizontal_alignment = asposepdfcloud.models.HorizontalAlignment.CENTER
annotation.rich_text = 'Rich Text'
annotation.subject = 'Subj'
annotation.z_index = 1
annotation.title = 'Title'

response =pdf_api.post_page_circle_annotations(
    file_name, page_number,  [annotation], folder=temp_folder)



# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from pprint import pformat
from six import iteritems
import re


class DocumentPrivilege(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'allow_print': 'bool',
        'allow_degraded_printing': 'bool',
        'allow_modify_contents': 'bool',
        'allow_copy': 'bool',
        'allow_modify_annotations': 'bool',
        'allow_fill_in': 'bool',
        'allow_screen_readers': 'bool',
        'allow_assembly': 'bool',
        'print_allow_level': 'int',
        'change_allow_level': 'int',
        'copy_allow_level': 'int'
    }

    attribute_map = {
        'allow_print': 'AllowPrint',
        'allow_degraded_printing': 'AllowDegradedPrinting',
        'allow_modify_contents': 'AllowModifyContents',
        'allow_copy': 'AllowCopy',
        'allow_modify_annotations': 'AllowModifyAnnotations',
        'allow_fill_in': 'AllowFillIn',
        'allow_screen_readers': 'AllowScreenReaders',
        'allow_assembly': 'AllowAssembly',
        'print_allow_level': 'PrintAllowLevel',
        'change_allow_level': 'ChangeAllowLevel',
        'copy_allow_level': 'CopyAllowLevel'
    }

    def __init__(self, allow_print=None, allow_degraded_printing=None, allow_modify_contents=None, allow_copy=None, allow_modify_annotations=None, allow_fill_in=None, allow_screen_readers=None, allow_assembly=None, print_allow_level=None, change_allow_level=None, copy_allow_level=None):
        """
        DocumentPrivilege - a model defined in Swagger
        """

        self._allow_print = None
        self._allow_degraded_printing = None
        self._allow_modify_contents = None
        self._allow_copy = None
        self._allow_modify_annotations = None
        self._allow_fill_in = None
        self._allow_screen_readers = None
        self._allow_assembly = None
        self._print_allow_level = None
        self._change_allow_level = None
        self._copy_allow_level = None

        if allow_print is not None:
          self.allow_print = allow_print
        if allow_degraded_printing is not None:
          self.allow_degraded_printing = allow_degraded_printing
        if allow_modify_contents is not None:
          self.allow_modify_contents = allow_modify_contents
        if allow_copy is not None:
          self.allow_copy = allow_copy
        if allow_modify_annotations is not None:
          self.allow_modify_annotations = allow_modify_annotations
        if allow_fill_in is not None:
          self.allow_fill_in = allow_fill_in
        if allow_screen_readers is not None:
          self.allow_screen_readers = allow_screen_readers
        if allow_assembly is not None:
          self.allow_assembly = allow_assembly
        if print_allow_level is not None:
          self.print_allow_level = print_allow_level
        if change_allow_level is not None:
          self.change_allow_level = change_allow_level
        if copy_allow_level is not None:
          self.copy_allow_level = copy_allow_level

    @property
    def allow_print(self):
        """
        Gets the allow_print of this DocumentPrivilege.
        Sets the permission which allow print or not.  true is allow and false or not set is forbidden.

        :return: The allow_print of this DocumentPrivilege.
        :rtype: bool
        """
        return self._allow_print

    @allow_print.setter
    def allow_print(self, allow_print):
        """
        Sets the allow_print of this DocumentPrivilege.
        Sets the permission which allow print or not.  true is allow and false or not set is forbidden.

        :param allow_print: The allow_print of this DocumentPrivilege.
        :type: bool
        """

        self._allow_print = allow_print

    @property
    def allow_degraded_printing(self):
        """
        Gets the allow_degraded_printing of this DocumentPrivilege.
        Sets the permission which allow degraded printing or not.  true is allow and false or not set is forbidden.

        :return: The allow_degraded_printing of this DocumentPrivilege.
        :rtype: bool
        """
        return self._allow_degraded_printing

    @allow_degraded_printing.setter
    def allow_degraded_printing(self, allow_degraded_printing):
        """
        Sets the allow_degraded_printing of this DocumentPrivilege.
        Sets the permission which allow degraded printing or not.  true is allow and false or not set is forbidden.

        :param allow_degraded_printing: The allow_degraded_printing of this DocumentPrivilege.
        :type: bool
        """

        self._allow_degraded_printing = allow_degraded_printing

    @property
    def allow_modify_contents(self):
        """
        Gets the allow_modify_contents of this DocumentPrivilege.
        Sets the permission which allow modify contents or not.  true is allow and false or not set is forbidden.

        :return: The allow_modify_contents of this DocumentPrivilege.
        :rtype: bool
        """
        return self._allow_modify_contents

    @allow_modify_contents.setter
    def allow_modify_contents(self, allow_modify_contents):
        """
        Sets the allow_modify_contents of this DocumentPrivilege.
        Sets the permission which allow modify contents or not.  true is allow and false or not set is forbidden.

        :param allow_modify_contents: The allow_modify_contents of this DocumentPrivilege.
        :type: bool
        """

        self._allow_modify_contents = allow_modify_contents

    @property
    def allow_copy(self):
        """
        Gets the allow_copy of this DocumentPrivilege.
        Sets the permission which allow copy or not.  true is allow and false or not set is forbidden.

        :return: The allow_copy of this DocumentPrivilege.
        :rtype: bool
        """
        return self._allow_copy

    @allow_copy.setter
    def allow_copy(self, allow_copy):
        """
        Sets the allow_copy of this DocumentPrivilege.
        Sets the permission which allow copy or not.  true is allow and false or not set is forbidden.

        :param allow_copy: The allow_copy of this DocumentPrivilege.
        :type: bool
        """

        self._allow_copy = allow_copy

    @property
    def allow_modify_annotations(self):
        """
        Gets the allow_modify_annotations of this DocumentPrivilege.
        Sets the permission which allow modify annotations or not.  true is allow and false or not set is forbidden.

        :return: The allow_modify_annotations of this DocumentPrivilege.
        :rtype: bool
        """
        return self._allow_modify_annotations

    @allow_modify_annotations.setter
    def allow_modify_annotations(self, allow_modify_annotations):
        """
        Sets the allow_modify_annotations of this DocumentPrivilege.
        Sets the permission which allow modify annotations or not.  true is allow and false or not set is forbidden.

        :param allow_modify_annotations: The allow_modify_annotations of this DocumentPrivilege.
        :type: bool
        """

        self._allow_modify_annotations = allow_modify_annotations

    @property
    def allow_fill_in(self):
        """
        Gets the allow_fill_in of this DocumentPrivilege.
        Sets the permission which allow fill in forms or not.  true is allow and false or not set is forbidden.

        :return: The allow_fill_in of this DocumentPrivilege.
        :rtype: bool
        """
        return self._allow_fill_in

    @allow_fill_in.setter
    def allow_fill_in(self, allow_fill_in):
        """
        Sets the allow_fill_in of this DocumentPrivilege.
        Sets the permission which allow fill in forms or not.  true is allow and false or not set is forbidden.

        :param allow_fill_in: The allow_fill_in of this DocumentPrivilege.
        :type: bool
        """

        self._allow_fill_in = allow_fill_in

    @property
    def allow_screen_readers(self):
        """
        Gets the allow_screen_readers of this DocumentPrivilege.
        Sets the permission which allow screen readers or not.  true is allow and false or not set is forbidden.

        :return: The allow_screen_readers of this DocumentPrivilege.
        :rtype: bool
        """
        return self._allow_screen_readers

    @allow_screen_readers.setter
    def allow_screen_readers(self, allow_screen_readers):
        """
        Sets the allow_screen_readers of this DocumentPrivilege.
        Sets the permission which allow screen readers or not.  true is allow and false or not set is forbidden.

        :param allow_screen_readers: The allow_screen_readers of this DocumentPrivilege.
        :type: bool
        """

        self._allow_screen_readers = allow_screen_readers

    @property
    def allow_assembly(self):
        """
        Gets the allow_assembly of this DocumentPrivilege.
        Sets the permission which allow assembly or not.  true is allow and false or not set is forbidden.

        :return: The allow_assembly of this DocumentPrivilege.
        :rtype: bool
        """
        return self._allow_assembly

    @allow_assembly.setter
    def allow_assembly(self, allow_assembly):
        """
        Sets the allow_assembly of this DocumentPrivilege.
        Sets the permission which allow assembly or not.  true is allow and false or not set is forbidden.

        :param allow_assembly: The allow_assembly of this DocumentPrivilege.
        :type: bool
        """

        self._allow_assembly = allow_assembly

    @property
    def print_allow_level(self):
        """
        Gets the print_allow_level of this DocumentPrivilege.
        Sets the print level of  document's privilege. Just as the Adobe Professional's Printing Allowed settings. 0: None. 1: Low Resolution (150 dpi). 2: High Resolution.

        :return: The print_allow_level of this DocumentPrivilege.
        :rtype: int
        """
        return self._print_allow_level

    @print_allow_level.setter
    def print_allow_level(self, print_allow_level):
        """
        Sets the print_allow_level of this DocumentPrivilege.
        Sets the print level of  document's privilege. Just as the Adobe Professional's Printing Allowed settings. 0: None. 1: Low Resolution (150 dpi). 2: High Resolution.

        :param print_allow_level: The print_allow_level of this DocumentPrivilege.
        :type: int
        """

        self._print_allow_level = print_allow_level

    @property
    def change_allow_level(self):
        """
        Gets the change_allow_level of this DocumentPrivilege.
        Sets the change level of  document's privilege. Just as the Adobe Professional's Changes Allowed settings. 0: None. 1: Inserting, Deleting and Rotating pages. 2: Filling in form fields and signing existing signature fields. 3: Commenting, filling in form fields, and signing existing signature fields. 4: Any except extracting pages.

        :return: The change_allow_level of this DocumentPrivilege.
        :rtype: int
        """
        return self._change_allow_level

    @change_allow_level.setter
    def change_allow_level(self, change_allow_level):
        """
        Sets the change_allow_level of this DocumentPrivilege.
        Sets the change level of  document's privilege. Just as the Adobe Professional's Changes Allowed settings. 0: None. 1: Inserting, Deleting and Rotating pages. 2: Filling in form fields and signing existing signature fields. 3: Commenting, filling in form fields, and signing existing signature fields. 4: Any except extracting pages.

        :param change_allow_level: The change_allow_level of this DocumentPrivilege.
        :type: int
        """

        self._change_allow_level = change_allow_level

    @property
    def copy_allow_level(self):
        """
        Gets the copy_allow_level of this DocumentPrivilege.
        Sets the copy level of  document's privilege. Just as the Adobe Professional's permission settings. 0: None. 1: Enable text access for screen reader devices for the visually impaired. 2: Enable copying of text, images and other content.

        :return: The copy_allow_level of this DocumentPrivilege.
        :rtype: int
        """
        return self._copy_allow_level

    @copy_allow_level.setter
    def copy_allow_level(self, copy_allow_level):
        """
        Sets the copy_allow_level of this DocumentPrivilege.
        Sets the copy level of  document's privilege. Just as the Adobe Professional's permission settings. 0: None. 1: Enable text access for screen reader devices for the visually impaired. 2: Enable copying of text, images and other content.

        :param copy_allow_level: The copy_allow_level of this DocumentPrivilege.
        :type: int
        """

        self._copy_allow_level = copy_allow_level

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, DocumentPrivilege):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



 from configuration import *
 file_name = 'PdfWithAnnotations.pdf'
      uploadFile(file_name)


        annotation = asposepdfcloud.models.PopupAnnotation()
        annotation.name = 'Name Updated'
        annotation.rect = asposepdfcloud.models.Rectangle(llx=100, lly=100, urx=200, ury=200)
        annotation.flags = [asposepdfcloud.models.AnnotationFlags.DEFAULT]
        annotation.horizontal_alignment = asposepdfcloud.models.HorizontalAlignment.CENTER
        annotation.z_index = 1
        annotation.modified = '02/02/2018 00:00:00.000 AM'

        response_annotations = self.pdf_api.get_document_popup_annotations(file_name, folder=self.temp_folder)
        self.assertEqual(response_annotations.code, 200)
        annotation_id = response_annotations.annotations.list[0].id

        response = self.pdf_api.put_popup_annotation(file_name, annotation_id, annotation, folder=self.temp_folder)


# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from __future__ import absolute_import

# import models into model package
from .annotation_flags import AnnotationFlags
from .annotation_state import AnnotationState
from .annotation_type import AnnotationType
from .antialiasing_processing_type import AntialiasingProcessingType
from .aspose_response import AsposeResponse
from .border import Border
from .border_corner_style import BorderCornerStyle
from .border_effect import BorderEffect
from .border_info import BorderInfo
from .border_style import BorderStyle
from .box_style import BoxStyle
from .cap_style import CapStyle
from .caption_position import CaptionPosition
from .caret_symbol import CaretSymbol
from .cell import Cell
from .cell_recognized import CellRecognized
from .color import Color
from .color_depth import ColorDepth
from .column_adjustment import ColumnAdjustment
from .compression_type import CompressionType
from .crypto_algorithm import CryptoAlgorithm
from .dash import Dash
from .default_page_config import DefaultPageConfig
from .direction import Direction
from .disc_usage import DiscUsage
from .doc_format import DocFormat
from .doc_mdp_access_permission_type import DocMDPAccessPermissionType
from .doc_recognition_mode import DocRecognitionMode
from .document_config import DocumentConfig
from .document_privilege import DocumentPrivilege
from .epub_recognition_mode import EpubRecognitionMode
from .error import Error
from .error_details import ErrorDetails
from .field_type import FieldType
from .file_icon import FileIcon
from .file_versions import FileVersions
from .files_list import FilesList
from .files_upload_result import FilesUploadResult
from .font_encoding_rules import FontEncodingRules
from .font_saving_modes import FontSavingModes
from .font_styles import FontStyles
from .free_text_intent import FreeTextIntent
from .graph_info import GraphInfo
from .horizontal_alignment import HorizontalAlignment
from .html_document_type import HtmlDocumentType
from .html_markup_generation_modes import HtmlMarkupGenerationModes
from .image_compression_version import ImageCompressionVersion
from .image_encoding import ImageEncoding
from .image_fragment import ImageFragment
from .image_src_type import ImageSrcType
from .image_template import ImageTemplate
from .image_templates_request import ImageTemplatesRequest
from .justification import Justification
from .letters_positioning_methods import LettersPositioningMethods
from .line_ending import LineEnding
from .line_intent import LineIntent
from .line_spacing import LineSpacing
from .link import Link
from .link_action_type import LinkActionType
from .link_element import LinkElement
from .link_highlighting_mode import LinkHighlightingMode
from .margin_info import MarginInfo
from .merge_documents import MergeDocuments
from .object_exist import ObjectExist
from .optimize_options import OptimizeOptions
from .option import Option
from .output_format import OutputFormat
from .page_layout import PageLayout
from .page_mode import PageMode
from .page_range import PageRange
from .page_word_count import PageWordCount
from .paragraph import Paragraph
from .parts_embedding_modes import PartsEmbeddingModes
from .pdf_a_type import PdfAType
from .permissions_flags import PermissionsFlags
from .point import Point
from .poly_intent import PolyIntent
from .position import Position
from .raster_images_saving_modes import RasterImagesSavingModes
from .rectangle import Rectangle
from .rotation import Rotation
from .row import Row
from .row_recognized import RowRecognized
from .segment import Segment
from .shape_type import ShapeType
from .signature import Signature
from .signature_custom_appearance import SignatureCustomAppearance
from .signature_type import SignatureType
from .sound_encoding import SoundEncoding
from .sound_icon import SoundIcon
from .split_range_pdf_options import SplitRangePdfOptions
from .split_result import SplitResult
from .stamp import Stamp
from .stamp_icon import StampIcon
from .stamp_type import StampType
from .storage_exist import StorageExist
from .storage_file import StorageFile
from .table_broken import TableBroken
from .text_horizontal_alignment import TextHorizontalAlignment
from .text_icon import TextIcon
from .text_line import TextLine
from .text_rect import TextRect
from .text_rects import TextRects
from .text_replace import TextReplace
from .text_replace_list_request import TextReplaceListRequest
from .text_state import TextState
from .text_style import TextStyle
from .timestamp_settings import TimestampSettings
from .vertical_alignment import VerticalAlignment
from .word_count import WordCount
from .wrap_mode import WrapMode
from .annotation import Annotation
from .annotations_info import AnnotationsInfo
from .annotations_info_response import AnnotationsInfoResponse
from .attachment import Attachment
from .attachment_response import AttachmentResponse
from .attachments import Attachments
from .attachments_response import AttachmentsResponse
from .bookmark import Bookmark
from .bookmark_response import BookmarkResponse
from .bookmarks import Bookmarks
from .bookmarks_response import BookmarksResponse
from .caret_annotation_response import CaretAnnotationResponse
from .caret_annotations import CaretAnnotations
from .caret_annotations_response import CaretAnnotationsResponse
from .check_box_field_response import CheckBoxFieldResponse
from .check_box_fields import CheckBoxFields
from .check_box_fields_response import CheckBoxFieldsResponse
from .circle_annotation_response import CircleAnnotationResponse
from .circle_annotations import CircleAnnotations
from .circle_annotations_response import CircleAnnotationsResponse
from .combo_box_field_response import ComboBoxFieldResponse
from .combo_box_fields import ComboBoxFields
from .combo_box_fields_response import ComboBoxFieldsResponse
from .display_properties import DisplayProperties
from .display_properties_response import DisplayPropertiesResponse
from .document import Document
from .document_page_response import DocumentPageResponse
from .document_pages_response import DocumentPagesResponse
from .document_properties import DocumentProperties
from .document_properties_response import DocumentPropertiesResponse
from .document_property import DocumentProperty
from .document_property_response import DocumentPropertyResponse
from .document_response import DocumentResponse
from .field import Field
from .field_response import FieldResponse
from .fields import Fields
from .fields_response import FieldsResponse
from .file_attachment_annotation_response import FileAttachmentAnnotationResponse
from .file_attachment_annotations import FileAttachmentAnnotations
from .file_attachment_annotations_response import FileAttachmentAnnotationsResponse
from .file_version import FileVersion
from .form_field import FormField
from .free_text_annotation_response import FreeTextAnnotationResponse
from .free_text_annotations import FreeTextAnnotations
from .free_text_annotations_response import FreeTextAnnotationsResponse
from .highlight_annotation_response import HighlightAnnotationResponse
from .highlight_annotations import HighlightAnnotations
from .highlight_annotations_response import HighlightAnnotationsResponse
from .image import Image
from .image_response import ImageResponse
from .images import Images
from .images_response import ImagesResponse
from .ink_annotation_response import InkAnnotationResponse
from .ink_annotations import InkAnnotations
from .ink_annotations_response import InkAnnotationsResponse
from .line_annotation_response import LineAnnotationResponse
from .line_annotations import LineAnnotations
from .line_annotations_response import LineAnnotationsResponse
from .link_annotation import LinkAnnotation
from .link_annotation_response import LinkAnnotationResponse
from .link_annotations import LinkAnnotations
from .link_annotations_response import LinkAnnotationsResponse
from .list_box_field_response import ListBoxFieldResponse
from .list_box_fields import ListBoxFields
from .list_box_fields_response import ListBoxFieldsResponse
from .movie_annotation_response import MovieAnnotationResponse
from .movie_annotations import MovieAnnotations
from .movie_annotations_response import MovieAnnotationsResponse
from .page import Page
from .pages import Pages
from .poly_line_annotation_response import PolyLineAnnotationResponse
from .poly_line_annotations import PolyLineAnnotations
from .poly_line_annotations_response import PolyLineAnnotationsResponse
from .polygon_annotation_response import PolygonAnnotationResponse
from .polygon_annotations import PolygonAnnotations
from .polygon_annotations_response import PolygonAnnotationsResponse
from .popup_annotation_response import PopupAnnotationResponse
from .popup_annotations import PopupAnnotations
from .popup_annotations_response import PopupAnnotationsResponse
from .radio_button_field_response import RadioButtonFieldResponse
from .radio_button_fields import RadioButtonFields
from .radio_button_fields_response import RadioButtonFieldsResponse
from .redaction_annotation_response import RedactionAnnotationResponse
from .redaction_annotations import RedactionAnnotations
from .redaction_annotations_response import RedactionAnnotationsResponse
from .screen_annotation_response import ScreenAnnotationResponse
from .screen_annotations import ScreenAnnotations
from .screen_annotations_response import ScreenAnnotationsResponse
from .signature_field_response import SignatureFieldResponse
from .signature_fields import SignatureFields
from .signature_fields_response import SignatureFieldsResponse
from .signature_verify_response import SignatureVerifyResponse
from .sound_annotation_response import SoundAnnotationResponse
from .sound_annotations import SoundAnnotations
from .sound_annotations_response import SoundAnnotationsResponse
from .split_result_document import SplitResultDocument
from .split_result_response import SplitResultResponse
from .square_annotation_response import SquareAnnotationResponse
from .square_annotations import SquareAnnotations
from .square_annotations_response import SquareAnnotationsResponse
from .squiggly_annotation_response import SquigglyAnnotationResponse
from .squiggly_annotations import SquigglyAnnotations
from .squiggly_annotations_response import SquigglyAnnotationsResponse
from .stamp_annotation_response import StampAnnotationResponse
from .stamp_annotations import StampAnnotations
from .stamp_annotations_response import StampAnnotationsResponse
from .stamp_base import StampBase
from .stamp_info import StampInfo
from .stamps_info import StampsInfo
from .stamps_info_response import StampsInfoResponse
from .strike_out_annotation_response import StrikeOutAnnotationResponse
from .strike_out_annotations import StrikeOutAnnotations
from .strike_out_annotations_response import StrikeOutAnnotationsResponse
from .table import Table
from .table_recognized import TableRecognized
from .table_recognized_response import TableRecognizedResponse
from .tables_recognized import TablesRecognized
from .tables_recognized_response import TablesRecognizedResponse
from .text_annotation_response import TextAnnotationResponse
from .text_annotations import TextAnnotations
from .text_annotations_response import TextAnnotationsResponse
from .text_box_field_response import TextBoxFieldResponse
from .text_box_fields import TextBoxFields
from .text_box_fields_response import TextBoxFieldsResponse
from .text_rects_response import TextRectsResponse
from .text_replace_response import TextReplaceResponse
from .underline_annotation_response import UnderlineAnnotationResponse
from .underline_annotations import UnderlineAnnotations
from .underline_annotations_response import UnderlineAnnotationsResponse
from .word_count_response import WordCountResponse
from .annotation_info import AnnotationInfo
from .check_box_field import CheckBoxField
from .choice_field import ChoiceField
from .image_footer import ImageFooter
from .image_header import ImageHeader
from .image_stamp import ImageStamp
from .markup_annotation import MarkupAnnotation
from .movie_annotation import MovieAnnotation
from .page_number_stamp import PageNumberStamp
from .pdf_page_stamp import PdfPageStamp
from .popup_annotation import PopupAnnotation
from .radio_button_option_field import RadioButtonOptionField
from .redaction_annotation import RedactionAnnotation
from .screen_annotation import ScreenAnnotation
from .signature_field import SignatureField
from .text_box_field import TextBoxField
from .text_footer import TextFooter
from .text_header import TextHeader
from .text_stamp import TextStamp
from .caret_annotation import CaretAnnotation
from .combo_box_field import ComboBoxField
from .common_figure_annotation import CommonFigureAnnotation
from .file_attachment_annotation import FileAttachmentAnnotation
from .free_text_annotation import FreeTextAnnotation
from .highlight_annotation import HighlightAnnotation
from .ink_annotation import InkAnnotation
from .line_annotation import LineAnnotation
from .list_box_field import ListBoxField
from .poly_annotation import PolyAnnotation
from .popup_annotation_with_parent import PopupAnnotationWithParent
from .radio_button_field import RadioButtonField
from .sound_annotation import SoundAnnotation
from .squiggly_annotation import SquigglyAnnotation
from .stamp_annotation import StampAnnotation
from .strike_out_annotation import StrikeOutAnnotation
from .text_annotation import TextAnnotation
from .underline_annotation import UnderlineAnnotation
from .circle_annotation import CircleAnnotation
from .poly_line_annotation import PolyLineAnnotation
from .polygon_annotation import PolygonAnnotation
from .square_annotation import SquareAnnotation



from configuration import *
file_name = 'PdfWithImages2.pdf'
append_file_name = '4pages.pdf'

uploadFile(file_name)
uploadFile(append_file_name)

append_document = asposepdfcloud.models.AppendDocument(
    temp_folder + '/' + append_file_name, start_page=2, end_page=4)

opts = {
    "append_document": append_document,
    "folder": temp_folder
}

response = pdf_api.post_append_document(file_name, **opts)

pprint(response)



# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from pprint import pformat
from six import iteritems
import re


class OptimizeOptions(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'password': 'str',
        'allow_reuse_page_content': 'bool',
        'compress_images': 'bool',
        'image_quality': 'int',
        'link_duplcate_streams': 'bool',
        'remove_unused_objects': 'bool',
        'remove_unused_streams': 'bool',
        'unembed_fonts': 'bool',
        'resize_images': 'bool',
        'max_resolution': 'int',
        'subset_fonts': 'bool',
        'remove_private_info': 'bool',
        'image_encoding': 'ImageEncoding',
        'image_compression_version': 'ImageCompressionVersion'
    }

    attribute_map = {
        'password': 'Password',
        'allow_reuse_page_content': 'AllowReusePageContent',
        'compress_images': 'CompressImages',
        'image_quality': 'ImageQuality',
        'link_duplcate_streams': 'LinkDuplcateStreams',
        'remove_unused_objects': 'RemoveUnusedObjects',
        'remove_unused_streams': 'RemoveUnusedStreams',
        'unembed_fonts': 'UnembedFonts',
        'resize_images': 'ResizeImages',
        'max_resolution': 'MaxResolution',
        'subset_fonts': 'SubsetFonts',
        'remove_private_info': 'RemovePrivateInfo',
        'image_encoding': 'ImageEncoding',
        'image_compression_version': 'ImageCompressionVersion'
    }

    def __init__(self, password=None, allow_reuse_page_content=None, compress_images=None, image_quality=None, link_duplcate_streams=None, remove_unused_objects=None, remove_unused_streams=None, unembed_fonts=None, resize_images=None, max_resolution=None, subset_fonts=None, remove_private_info=None, image_encoding=None, image_compression_version=None):
        """
        OptimizeOptions - a model defined in Swagger
        """

        self._password = None
        self._allow_reuse_page_content = None
        self._compress_images = None
        self._image_quality = None
        self._link_duplcate_streams = None
        self._remove_unused_objects = None
        self._remove_unused_streams = None
        self._unembed_fonts = None
        self._resize_images = None
        self._max_resolution = None
        self._subset_fonts = None
        self._remove_private_info = None
        self._image_encoding = None
        self._image_compression_version = None

        if password is not None:
          self.password = password
        if allow_reuse_page_content is not None:
          self.allow_reuse_page_content = allow_reuse_page_content
        if compress_images is not None:
          self.compress_images = compress_images
        if image_quality is not None:
          self.image_quality = image_quality
        if link_duplcate_streams is not None:
          self.link_duplcate_streams = link_duplcate_streams
        if remove_unused_objects is not None:
          self.remove_unused_objects = remove_unused_objects
        if remove_unused_streams is not None:
          self.remove_unused_streams = remove_unused_streams
        if unembed_fonts is not None:
          self.unembed_fonts = unembed_fonts
        if resize_images is not None:
          self.resize_images = resize_images
        if max_resolution is not None:
          self.max_resolution = max_resolution
        if subset_fonts is not None:
          self.subset_fonts = subset_fonts
        if remove_private_info is not None:
          self.remove_private_info = remove_private_info
        if image_encoding is not None:
          self.image_encoding = image_encoding
        if image_compression_version is not None:
          self.image_compression_version = image_compression_version

    @property
    def password(self):
        """
        Gets the password of this OptimizeOptions.
        Specifies document password (if any) encoded with base-64.

        :return: The password of this OptimizeOptions.
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """
        Sets the password of this OptimizeOptions.
        Specifies document password (if any) encoded with base-64.

        :param password: The password of this OptimizeOptions.
        :type: str
        """

        self._password = password

    @property
    def allow_reuse_page_content(self):
        """
        Gets the allow_reuse_page_content of this OptimizeOptions.
        If true page contents will be reused when document is optimized for equal pages.

        :return: The allow_reuse_page_content of this OptimizeOptions.
        :rtype: bool
        """
        return self._allow_reuse_page_content

    @allow_reuse_page_content.setter
    def allow_reuse_page_content(self, allow_reuse_page_content):
        """
        Sets the allow_reuse_page_content of this OptimizeOptions.
        If true page contents will be reused when document is optimized for equal pages.

        :param allow_reuse_page_content: The allow_reuse_page_content of this OptimizeOptions.
        :type: bool
        """

        self._allow_reuse_page_content = allow_reuse_page_content

    @property
    def compress_images(self):
        """
        Gets the compress_images of this OptimizeOptions.
        If this flag is set to true images will be compressed in the document. Compression level is specified with ImageQuality property.

        :return: The compress_images of this OptimizeOptions.
        :rtype: bool
        """
        return self._compress_images

    @compress_images.setter
    def compress_images(self, compress_images):
        """
        Sets the compress_images of this OptimizeOptions.
        If this flag is set to true images will be compressed in the document. Compression level is specified with ImageQuality property.

        :param compress_images: The compress_images of this OptimizeOptions.
        :type: bool
        """

        self._compress_images = compress_images

    @property
    def image_quality(self):
        """
        Gets the image_quality of this OptimizeOptions.
        Specifies level of image compression when CompressImages flag is used.

        :return: The image_quality of this OptimizeOptions.
        :rtype: int
        """
        return self._image_quality

    @image_quality.setter
    def image_quality(self, image_quality):
        """
        Sets the image_quality of this OptimizeOptions.
        Specifies level of image compression when CompressImages flag is used.

        :param image_quality: The image_quality of this OptimizeOptions.
        :type: int
        """

        self._image_quality = image_quality

    @property
    def link_duplcate_streams(self):
        """
        Gets the link_duplcate_streams of this OptimizeOptions.
        If this flag is set to true, Resource streams will be analyzed. If duplicate streams are found (i.e. if stream contents is equal), then thees streams will be stored as one object.  This allows to decrease document size in some cases (for example, when same document was concatenated multiple times).

        :return: The link_duplcate_streams of this OptimizeOptions.
        :rtype: bool
        """
        return self._link_duplcate_streams

    @link_duplcate_streams.setter
    def link_duplcate_streams(self, link_duplcate_streams):
        """
        Sets the link_duplcate_streams of this OptimizeOptions.
        If this flag is set to true, Resource streams will be analyzed. If duplicate streams are found (i.e. if stream contents is equal), then thees streams will be stored as one object.  This allows to decrease document size in some cases (for example, when same document was concatenated multiple times).

        :param link_duplcate_streams: The link_duplcate_streams of this OptimizeOptions.
        :type: bool
        """

        self._link_duplcate_streams = link_duplcate_streams

    @property
    def remove_unused_objects(self):
        """
        Gets the remove_unused_objects of this OptimizeOptions.
        If this flag is set to true, all document objects will be checked and unused objects (i.e. objects which does not have any reference) are removed from document.

        :return: The remove_unused_objects of this OptimizeOptions.
        :rtype: bool
        """
        return self._remove_unused_objects

    @remove_unused_objects.setter
    def remove_unused_objects(self, remove_unused_objects):
        """
        Sets the remove_unused_objects of this OptimizeOptions.
        If this flag is set to true, all document objects will be checked and unused objects (i.e. objects which does not have any reference) are removed from document.

        :param remove_unused_objects: The remove_unused_objects of this OptimizeOptions.
        :type: bool
        """

        self._remove_unused_objects = remove_unused_objects

    @property
    def remove_unused_streams(self):
        """
        Gets the remove_unused_streams of this OptimizeOptions.
        If this flag set to true, every resource is checked on it's usage. If resource is never used, then resources is removed. This may decrease document size for example when pages were extracted from document. 

        :return: The remove_unused_streams of this OptimizeOptions.
        :rtype: bool
        """
        return self._remove_unused_streams

    @remove_unused_streams.setter
    def remove_unused_streams(self, remove_unused_streams):
        """
        Sets the remove_unused_streams of this OptimizeOptions.
        If this flag set to true, every resource is checked on it's usage. If resource is never used, then resources is removed. This may decrease document size for example when pages were extracted from document. 

        :param remove_unused_streams: The remove_unused_streams of this OptimizeOptions.
        :type: bool
        """

        self._remove_unused_streams = remove_unused_streams

    @property
    def unembed_fonts(self):
        """
        Gets the unembed_fonts of this OptimizeOptions.
        Make fonts not embedded if set to true. 

        :return: The unembed_fonts of this OptimizeOptions.
        :rtype: bool
        """
        return self._unembed_fonts

    @unembed_fonts.setter
    def unembed_fonts(self, unembed_fonts):
        """
        Sets the unembed_fonts of this OptimizeOptions.
        Make fonts not embedded if set to true. 

        :param unembed_fonts: The unembed_fonts of this OptimizeOptions.
        :type: bool
        """

        self._unembed_fonts = unembed_fonts

    @property
    def resize_images(self):
        """
        Gets the resize_images of this OptimizeOptions.
        If this flag set to true and CompressImages is true images will be resized if image resolution is greater then specified MaxResolution parameter.

        :return: The resize_images of this OptimizeOptions.
        :rtype: bool
        """
        return self._resize_images

    @resize_images.setter
    def resize_images(self, resize_images):
        """
        Sets the resize_images of this OptimizeOptions.
        If this flag set to true and CompressImages is true images will be resized if image resolution is greater then specified MaxResolution parameter.

        :param resize_images: The resize_images of this OptimizeOptions.
        :type: bool
        """

        self._resize_images = resize_images

    @property
    def max_resolution(self):
        """
        Gets the max_resolution of this OptimizeOptions.
        Specifies maximum resolution of images. If image has higher resolution it will be scaled.

        :return: The max_resolution of this OptimizeOptions.
        :rtype: int
        """
        return self._max_resolution

    @max_resolution.setter
    def max_resolution(self, max_resolution):
        """
        Sets the max_resolution of this OptimizeOptions.
        Specifies maximum resolution of images. If image has higher resolution it will be scaled.

        :param max_resolution: The max_resolution of this OptimizeOptions.
        :type: int
        """

        self._max_resolution = max_resolution

    @property
    def subset_fonts(self):
        """
        Gets the subset_fonts of this OptimizeOptions.
        Fonts will be converted into subsets if set to true.

        :return: The subset_fonts of this OptimizeOptions.
        :rtype: bool
        """
        return self._subset_fonts

    @subset_fonts.setter
    def subset_fonts(self, subset_fonts):
        """
        Sets the subset_fonts of this OptimizeOptions.
        Fonts will be converted into subsets if set to true.

        :param subset_fonts: The subset_fonts of this OptimizeOptions.
        :type: bool
        """

        self._subset_fonts = subset_fonts

    @property
    def remove_private_info(self):
        """
        Gets the remove_private_info of this OptimizeOptions.
        Remove private information (page piece info).

        :return: The remove_private_info of this OptimizeOptions.
        :rtype: bool
        """
        return self._remove_private_info

    @remove_private_info.setter
    def remove_private_info(self, remove_private_info):
        """
        Sets the remove_private_info of this OptimizeOptions.
        Remove private information (page piece info).

        :param remove_private_info: The remove_private_info of this OptimizeOptions.
        :type: bool
        """

        self._remove_private_info = remove_private_info

    @property
    def image_encoding(self):
        """
        Gets the image_encoding of this OptimizeOptions.
        Image encode which will be used.

        :return: The image_encoding of this OptimizeOptions.
        :rtype: ImageEncoding
        """
        return self._image_encoding

    @image_encoding.setter
    def image_encoding(self, image_encoding):
        """
        Sets the image_encoding of this OptimizeOptions.
        Image encode which will be used.

        :param image_encoding: The image_encoding of this OptimizeOptions.
        :type: ImageEncoding
        """

        self._image_encoding = image_encoding

    @property
    def image_compression_version(self):
        """
        Gets the image_compression_version of this OptimizeOptions.
        Version of compression algorithm. Possible values are: \"Standard\" - standard compression, \"Fast\" - fast (improved compression which is faster then standard but may be applicable not for all images), \"Mixed\" - mixed (standard compression is applied to images which can not be compressed by  faster algorithm, this may give best compression but more slow then \"Fast\" algorithm. Version \"Fast\" is not applicable for resizing images (standard method will be used). Default is \"Standard\".

        :return: The image_compression_version of this OptimizeOptions.
        :rtype: ImageCompressionVersion
        """
        return self._image_compression_version

    @image_compression_version.setter
    def image_compression_version(self, image_compression_version):
        """
        Sets the image_compression_version of this OptimizeOptions.
        Version of compression algorithm. Possible values are: \"Standard\" - standard compression, \"Fast\" - fast (improved compression which is faster then standard but may be applicable not for all images), \"Mixed\" - mixed (standard compression is applied to images which can not be compressed by  faster algorithm, this may give best compression but more slow then \"Fast\" algorithm. Version \"Fast\" is not applicable for resizing images (standard method will be used). Default is \"Standard\".

        :param image_compression_version: The image_compression_version of this OptimizeOptions.
        :type: ImageCompressionVersion
        """

        self._image_compression_version = image_compression_version

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, OptimizeOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from pprint import pformat
from six import iteritems
import re


class Cell(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_no_border': 'bool',
        'margin': 'MarginInfo',
        'border': 'BorderInfo',
        'background_color': 'Color',
        'background_image_file': 'str',
        'background_image_storage_file': 'str',
        'alignment': 'HorizontalAlignment',
        'default_cell_text_state': 'TextState',
        'paragraphs': 'list[TextRect]',
        'is_word_wrapped': 'bool',
        'vertical_alignment': 'VerticalAlignment',
        'col_span': 'int',
        'row_span': 'int',
        'width': 'float',
        'html_fragment': 'str',
        'images': 'list[ImageFragment]'
    }

    attribute_map = {
        'is_no_border': 'IsNoBorder',
        'margin': 'Margin',
        'border': 'Border',
        'background_color': 'BackgroundColor',
        'background_image_file': 'BackgroundImageFile',
        'background_image_storage_file': 'BackgroundImageStorageFile',
        'alignment': 'Alignment',
        'default_cell_text_state': 'DefaultCellTextState',
        'paragraphs': 'Paragraphs',
        'is_word_wrapped': 'IsWordWrapped',
        'vertical_alignment': 'VerticalAlignment',
        'col_span': 'ColSpan',
        'row_span': 'RowSpan',
        'width': 'Width',
        'html_fragment': 'HtmlFragment',
        'images': 'Images'
    }

    def __init__(self, is_no_border=None, margin=None, border=None, background_color=None, background_image_file=None, background_image_storage_file=None, alignment=None, default_cell_text_state=None, paragraphs=None, is_word_wrapped=None, vertical_alignment=None, col_span=None, row_span=None, width=None, html_fragment=None, images=None):
        """
        Cell - a model defined in Swagger
        """

        self._is_no_border = None
        self._margin = None
        self._border = None
        self._background_color = None
        self._background_image_file = None
        self._background_image_storage_file = None
        self._alignment = None
        self._default_cell_text_state = None
        self._paragraphs = None
        self._is_word_wrapped = None
        self._vertical_alignment = None
        self._col_span = None
        self._row_span = None
        self._width = None
        self._html_fragment = None
        self._images = None

        if is_no_border is not None:
          self.is_no_border = is_no_border
        if margin is not None:
          self.margin = margin
        if border is not None:
          self.border = border
        if background_color is not None:
          self.background_color = background_color
        if background_image_file is not None:
          self.background_image_file = background_image_file
        if background_image_storage_file is not None:
          self.background_image_storage_file = background_image_storage_file
        if alignment is not None:
          self.alignment = alignment
        if default_cell_text_state is not None:
          self.default_cell_text_state = default_cell_text_state
        if paragraphs is not None:
          self.paragraphs = paragraphs
        if is_word_wrapped is not None:
          self.is_word_wrapped = is_word_wrapped
        if vertical_alignment is not None:
          self.vertical_alignment = vertical_alignment
        if col_span is not None:
          self.col_span = col_span
        if row_span is not None:
          self.row_span = row_span
        if width is not None:
          self.width = width
        if html_fragment is not None:
          self.html_fragment = html_fragment
        if images is not None:
          self.images = images

    @property
    def is_no_border(self):
        """
        Gets the is_no_border of this Cell.
        Gets or sets the cell have border.

        :return: The is_no_border of this Cell.
        :rtype: bool
        """
        return self._is_no_border

    @is_no_border.setter
    def is_no_border(self, is_no_border):
        """
        Sets the is_no_border of this Cell.
        Gets or sets the cell have border.

        :param is_no_border: The is_no_border of this Cell.
        :type: bool
        """

        self._is_no_border = is_no_border

    @property
    def margin(self):
        """
        Gets the margin of this Cell.
        Gets or sets the padding.

        :return: The margin of this Cell.
        :rtype: MarginInfo
        """
        return self._margin

    @margin.setter
    def margin(self, margin):
        """
        Sets the margin of this Cell.
        Gets or sets the padding.

        :param margin: The margin of this Cell.
        :type: MarginInfo
        """

        self._margin = margin

    @property
    def border(self):
        """
        Gets the border of this Cell.
        Gets or sets the border.

        :return: The border of this Cell.
        :rtype: BorderInfo
        """
        return self._border

    @border.setter
    def border(self, border):
        """
        Sets the border of this Cell.
        Gets or sets the border.

        :param border: The border of this Cell.
        :type: BorderInfo
        """

        self._border = border

    @property
    def background_color(self):
        """
        Gets the background_color of this Cell.
        Gets or sets the background color.

        :return: The background_color of this Cell.
        :rtype: Color
        """
        return self._background_color

    @background_color.setter
    def background_color(self, background_color):
        """
        Sets the background_color of this Cell.
        Gets or sets the background color.

        :param background_color: The background_color of this Cell.
        :type: Color
        """

        self._background_color = background_color

    @property
    def background_image_file(self):
        """
        Gets the background_image_file of this Cell.
        Gets or sets the background image file.

        :return: The background_image_file of this Cell.
        :rtype: str
        """
        return self._background_image_file

    @background_image_file.setter
    def background_image_file(self, background_image_file):
        """
        Sets the background_image_file of this Cell.
        Gets or sets the background image file.

        :param background_image_file: The background_image_file of this Cell.
        :type: str
        """

        self._background_image_file = background_image_file

    @property
    def background_image_storage_file(self):
        """
        Gets the background_image_storage_file of this Cell.
        Gets or sets path of the background image file from storage.

        :return: The background_image_storage_file of this Cell.
        :rtype: str
        """
        return self._background_image_storage_file

    @background_image_storage_file.setter
    def background_image_storage_file(self, background_image_storage_file):
        """
        Sets the background_image_storage_file of this Cell.
        Gets or sets path of the background image file from storage.

        :param background_image_storage_file: The background_image_storage_file of this Cell.
        :type: str
        """

        self._background_image_storage_file = background_image_storage_file

    @property
    def alignment(self):
        """
        Gets the alignment of this Cell.
        Gets or sets the alignment.

        :return: The alignment of this Cell.
        :rtype: HorizontalAlignment
        """
        return self._alignment

    @alignment.setter
    def alignment(self, alignment):
        """
        Sets the alignment of this Cell.
        Gets or sets the alignment.

        :param alignment: The alignment of this Cell.
        :type: HorizontalAlignment
        """

        self._alignment = alignment

    @property
    def default_cell_text_state(self):
        """
        Gets the default_cell_text_state of this Cell.
        Gets or sets the default cell text state.

        :return: The default_cell_text_state of this Cell.
        :rtype: TextState
        """
        return self._default_cell_text_state

    @default_cell_text_state.setter
    def default_cell_text_state(self, default_cell_text_state):
        """
        Sets the default_cell_text_state of this Cell.
        Gets or sets the default cell text state.

        :param default_cell_text_state: The default_cell_text_state of this Cell.
        :type: TextState
        """

        self._default_cell_text_state = default_cell_text_state

    @property
    def paragraphs(self):
        """
        Gets the paragraphs of this Cell.
        Gets or sets the cell's formatted text.

        :return: The paragraphs of this Cell.
        :rtype: list[TextRect]
        """
        return self._paragraphs

    @paragraphs.setter
    def paragraphs(self, paragraphs):
        """
        Sets the paragraphs of this Cell.
        Gets or sets the cell's formatted text.

        :param paragraphs: The paragraphs of this Cell.
        :type: list[TextRect]
        """

        self._paragraphs = paragraphs

    @property
    def is_word_wrapped(self):
        """
        Gets the is_word_wrapped of this Cell.
        Gets or sets the cell's text word wrapped.

        :return: The is_word_wrapped of this Cell.
        :rtype: bool
        """
        return self._is_word_wrapped

    @is_word_wrapped.setter
    def is_word_wrapped(self, is_word_wrapped):
        """
        Sets the is_word_wrapped of this Cell.
        Gets or sets the cell's text word wrapped.

        :param is_word_wrapped: The is_word_wrapped of this Cell.
        :type: bool
        """

        self._is_word_wrapped = is_word_wrapped

    @property
    def vertical_alignment(self):
        """
        Gets the vertical_alignment of this Cell.
        Gets or sets the vertical alignment.

        :return: The vertical_alignment of this Cell.
        :rtype: VerticalAlignment
        """
        return self._vertical_alignment

    @vertical_alignment.setter
    def vertical_alignment(self, vertical_alignment):
        """
        Sets the vertical_alignment of this Cell.
        Gets or sets the vertical alignment.

        :param vertical_alignment: The vertical_alignment of this Cell.
        :type: VerticalAlignment
        """

        self._vertical_alignment = vertical_alignment

    @property
    def col_span(self):
        """
        Gets the col_span of this Cell.
        Gets or sets the column span.

        :return: The col_span of this Cell.
        :rtype: int
        """
        return self._col_span

    @col_span.setter
    def col_span(self, col_span):
        """
        Sets the col_span of this Cell.
        Gets or sets the column span.

        :param col_span: The col_span of this Cell.
        :type: int
        """

        self._col_span = col_span

    @property
    def row_span(self):
        """
        Gets the row_span of this Cell.
        Gets or sets the row span.

        :return: The row_span of this Cell.
        :rtype: int
        """
        return self._row_span

    @row_span.setter
    def row_span(self, row_span):
        """
        Sets the row_span of this Cell.
        Gets or sets the row span.

        :param row_span: The row_span of this Cell.
        :type: int
        """

        self._row_span = row_span

    @property
    def width(self):
        """
        Gets the width of this Cell.
        Gets or sets the column width.

        :return: The width of this Cell.
        :rtype: float
        """
        return self._width

    @width.setter
    def width(self, width):
        """
        Sets the width of this Cell.
        Gets or sets the column width.

        :param width: The width of this Cell.
        :type: float
        """

        self._width = width

    @property
    def html_fragment(self):
        """
        Gets the html_fragment of this Cell.
        Gets or sets Html fragment.

        :return: The html_fragment of this Cell.
        :rtype: str
        """
        return self._html_fragment

    @html_fragment.setter
    def html_fragment(self, html_fragment):
        """
        Sets the html_fragment of this Cell.
        Gets or sets Html fragment.

        :param html_fragment: The html_fragment of this Cell.
        :type: str
        """

        self._html_fragment = html_fragment

    @property
    def images(self):
        """
        Gets the images of this Cell.
        Gets or sets ImageFragment list.

        :return: The images of this Cell.
        :rtype: list[ImageFragment]
        """
        return self._images

    @images.setter
    def images(self, images):
        """
        Sets the images of this Cell.
        Gets or sets ImageFragment list.

        :param images: The images of this Cell.
        :type: list[ImageFragment]
        """

        self._images = images

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Cell):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from pprint import pformat
from six import iteritems
import re


class DisplayProperties(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'links': 'list[Link]',
        'center_window': 'bool',
        'direction': 'Direction',
        'display_doc_title': 'bool',
        'hide_menu_bar': 'bool',
        'hide_tool_bar': 'bool',
        'hide_window_ui': 'bool',
        'non_full_screen_page_mode': 'PageMode',
        'page_layout': 'PageLayout',
        'page_mode': 'PageMode'
    }

    attribute_map = {
        'links': 'Links',
        'center_window': 'CenterWindow',
        'direction': 'Direction',
        'display_doc_title': 'DisplayDocTitle',
        'hide_menu_bar': 'HideMenuBar',
        'hide_tool_bar': 'HideToolBar',
        'hide_window_ui': 'HideWindowUI',
        'non_full_screen_page_mode': 'NonFullScreenPageMode',
        'page_layout': 'PageLayout',
        'page_mode': 'PageMode'
    }

    def __init__(self, links=None, center_window=None, direction=None, display_doc_title=None, hide_menu_bar=None, hide_tool_bar=None, hide_window_ui=None, non_full_screen_page_mode=None, page_layout=None, page_mode=None):
        """
        DisplayProperties - a model defined in Swagger
        """

        self._links = None
        self._center_window = None
        self._direction = None
        self._display_doc_title = None
        self._hide_menu_bar = None
        self._hide_tool_bar = None
        self._hide_window_ui = None
        self._non_full_screen_page_mode = None
        self._page_layout = None
        self._page_mode = None

        if links is not None:
          self.links = links
        if center_window is not None:
          self.center_window = center_window
        if direction is not None:
          self.direction = direction
        if display_doc_title is not None:
          self.display_doc_title = display_doc_title
        if hide_menu_bar is not None:
          self.hide_menu_bar = hide_menu_bar
        if hide_tool_bar is not None:
          self.hide_tool_bar = hide_tool_bar
        if hide_window_ui is not None:
          self.hide_window_ui = hide_window_ui
        if non_full_screen_page_mode is not None:
          self.non_full_screen_page_mode = non_full_screen_page_mode
        if page_layout is not None:
          self.page_layout = page_layout
        if page_mode is not None:
          self.page_mode = page_mode

    @property
    def links(self):
        """
        Gets the links of this DisplayProperties.
        Link to the document.

        :return: The links of this DisplayProperties.
        :rtype: list[Link]
        """
        return self._links

    @links.setter
    def links(self, links):
        """
        Sets the links of this DisplayProperties.
        Link to the document.

        :param links: The links of this DisplayProperties.
        :type: list[Link]
        """

        self._links = links

    @property
    def center_window(self):
        """
        Gets the center_window of this DisplayProperties.
        Gets or sets flag specifying whether position of the document's window will be centerd on the screen.

        :return: The center_window of this DisplayProperties.
        :rtype: bool
        """
        return self._center_window

    @center_window.setter
    def center_window(self, center_window):
        """
        Sets the center_window of this DisplayProperties.
        Gets or sets flag specifying whether position of the document's window will be centerd on the screen.

        :param center_window: The center_window of this DisplayProperties.
        :type: bool
        """

        self._center_window = center_window

    @property
    def direction(self):
        """
        Gets the direction of this DisplayProperties.
        Gets or sets reading order of text: L2R (left to right) or R2L (right to left).

        :return: The direction of this DisplayProperties.
        :rtype: Direction
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this DisplayProperties.
        Gets or sets reading order of text: L2R (left to right) or R2L (right to left).

        :param direction: The direction of this DisplayProperties.
        :type: Direction
        """

        self._direction = direction

    @property
    def display_doc_title(self):
        """
        Gets the display_doc_title of this DisplayProperties.
        Gets or sets flag specifying whether document's window title bar should display document title.

        :return: The display_doc_title of this DisplayProperties.
        :rtype: bool
        """
        return self._display_doc_title

    @display_doc_title.setter
    def display_doc_title(self, display_doc_title):
        """
        Sets the display_doc_title of this DisplayProperties.
        Gets or sets flag specifying whether document's window title bar should display document title.

        :param display_doc_title: The display_doc_title of this DisplayProperties.
        :type: bool
        """

        self._display_doc_title = display_doc_title

    @property
    def hide_menu_bar(self):
        """
        Gets the hide_menu_bar of this DisplayProperties.
        Gets or sets flag specifying whether menu bar should be hidden when document is active.

        :return: The hide_menu_bar of this DisplayProperties.
        :rtype: bool
        """
        return self._hide_menu_bar

    @hide_menu_bar.setter
    def hide_menu_bar(self, hide_menu_bar):
        """
        Sets the hide_menu_bar of this DisplayProperties.
        Gets or sets flag specifying whether menu bar should be hidden when document is active.

        :param hide_menu_bar: The hide_menu_bar of this DisplayProperties.
        :type: bool
        """

        self._hide_menu_bar = hide_menu_bar

    @property
    def hide_tool_bar(self):
        """
        Gets the hide_tool_bar of this DisplayProperties.
        Gets or sets flag specifying whether toolbar should be hidden when document is active.

        :return: The hide_tool_bar of this DisplayProperties.
        :rtype: bool
        """
        return self._hide_tool_bar

    @hide_tool_bar.setter
    def hide_tool_bar(self, hide_tool_bar):
        """
        Sets the hide_tool_bar of this DisplayProperties.
        Gets or sets flag specifying whether toolbar should be hidden when document is active.

        :param hide_tool_bar: The hide_tool_bar of this DisplayProperties.
        :type: bool
        """

        self._hide_tool_bar = hide_tool_bar

    @property
    def hide_window_ui(self):
        """
        Gets the hide_window_ui of this DisplayProperties.
        Gets or sets flag specifying whether user interface elements should be hidden when document is active.

        :return: The hide_window_ui of this DisplayProperties.
        :rtype: bool
        """
        return self._hide_window_ui

    @hide_window_ui.setter
    def hide_window_ui(self, hide_window_ui):
        """
        Sets the hide_window_ui of this DisplayProperties.
        Gets or sets flag specifying whether user interface elements should be hidden when document is active.

        :param hide_window_ui: The hide_window_ui of this DisplayProperties.
        :type: bool
        """

        self._hide_window_ui = hide_window_ui

    @property
    def non_full_screen_page_mode(self):
        """
        Gets the non_full_screen_page_mode of this DisplayProperties.
        Gets or sets page mode, specifying how to display the document on exiting full-screen mode.

        :return: The non_full_screen_page_mode of this DisplayProperties.
        :rtype: PageMode
        """
        return self._non_full_screen_page_mode

    @non_full_screen_page_mode.setter
    def non_full_screen_page_mode(self, non_full_screen_page_mode):
        """
        Sets the non_full_screen_page_mode of this DisplayProperties.
        Gets or sets page mode, specifying how to display the document on exiting full-screen mode.

        :param non_full_screen_page_mode: The non_full_screen_page_mode of this DisplayProperties.
        :type: PageMode
        """

        self._non_full_screen_page_mode = non_full_screen_page_mode

    @property
    def page_layout(self):
        """
        Gets the page_layout of this DisplayProperties.
        Gets or sets page layout which shall be used when the document is opened.

        :return: The page_layout of this DisplayProperties.
        :rtype: PageLayout
        """
        return self._page_layout

    @page_layout.setter
    def page_layout(self, page_layout):
        """
        Sets the page_layout of this DisplayProperties.
        Gets or sets page layout which shall be used when the document is opened.

        :param page_layout: The page_layout of this DisplayProperties.
        :type: PageLayout
        """

        self._page_layout = page_layout

    @property
    def page_mode(self):
        """
        Gets the page_mode of this DisplayProperties.
        Gets or sets page mode, specifying how document should be displayed when opened.

        :return: The page_mode of this DisplayProperties.
        :rtype: PageMode
        """
        return self._page_mode

    @page_mode.setter
    def page_mode(self, page_mode):
        """
        Sets the page_mode of this DisplayProperties.
        Gets or sets page mode, specifying how document should be displayed when opened.

        :param page_mode: The page_mode of this DisplayProperties.
        :type: PageMode
        """

        self._page_mode = page_mode

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, DisplayProperties):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from pprint import pformat
from six import iteritems
import re


class StampBase(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'links': 'list[Link]',
        'background': 'bool',
        'horizontal_alignment': 'HorizontalAlignment',
        'opacity': 'float',
        'rotate': 'Rotation',
        'rotate_angle': 'float',
        'x_indent': 'float',
        'y_indent': 'float',
        'zoom': 'float'
    }

    attribute_map = {
        'links': 'Links',
        'background': 'Background',
        'horizontal_alignment': 'HorizontalAlignment',
        'opacity': 'Opacity',
        'rotate': 'Rotate',
        'rotate_angle': 'RotateAngle',
        'x_indent': 'XIndent',
        'y_indent': 'YIndent',
        'zoom': 'Zoom'
    }

    def __init__(self, links=None, background=None, horizontal_alignment=None, opacity=None, rotate=None, rotate_angle=None, x_indent=None, y_indent=None, zoom=None):
        """
        StampBase - a model defined in Swagger
        """

        self._links = None
        self._background = None
        self._horizontal_alignment = None
        self._opacity = None
        self._rotate = None
        self._rotate_angle = None
        self._x_indent = None
        self._y_indent = None
        self._zoom = None

        if links is not None:
          self.links = links
        if background is not None:
          self.background = background
        if horizontal_alignment is not None:
          self.horizontal_alignment = horizontal_alignment
        if opacity is not None:
          self.opacity = opacity
        if rotate is not None:
          self.rotate = rotate
        if rotate_angle is not None:
          self.rotate_angle = rotate_angle
        if x_indent is not None:
          self.x_indent = x_indent
        if y_indent is not None:
          self.y_indent = y_indent
        if zoom is not None:
          self.zoom = zoom

    @property
    def links(self):
        """
        Gets the links of this StampBase.
        Link to the document.

        :return: The links of this StampBase.
        :rtype: list[Link]
        """
        return self._links

    @links.setter
    def links(self, links):
        """
        Sets the links of this StampBase.
        Link to the document.

        :param links: The links of this StampBase.
        :type: list[Link]
        """

        self._links = links

    @property
    def background(self):
        """
        Gets the background of this StampBase.
        Sets or gets a bool value that indicates the content is stamped as background. If the value is true, the stamp content is layed at the bottom. By defalt, the value is false, the stamp content is layed at the top.

        :return: The background of this StampBase.
        :rtype: bool
        """
        return self._background

    @background.setter
    def background(self, background):
        """
        Sets the background of this StampBase.
        Sets or gets a bool value that indicates the content is stamped as background. If the value is true, the stamp content is layed at the bottom. By defalt, the value is false, the stamp content is layed at the top.

        :param background: The background of this StampBase.
        :type: bool
        """

        self._background = background

    @property
    def horizontal_alignment(self):
        """
        Gets the horizontal_alignment of this StampBase.
        Gets or sets Horizontal alignment of stamp on the page. 

        :return: The horizontal_alignment of this StampBase.
        :rtype: HorizontalAlignment
        """
        return self._horizontal_alignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, horizontal_alignment):
        """
        Sets the horizontal_alignment of this StampBase.
        Gets or sets Horizontal alignment of stamp on the page. 

        :param horizontal_alignment: The horizontal_alignment of this StampBase.
        :type: HorizontalAlignment
        """

        self._horizontal_alignment = horizontal_alignment

    @property
    def opacity(self):
        """
        Gets the opacity of this StampBase.
        Gets or sets a value to indicate the stamp opacity. The value is from 0.0 to 1.0. By default the value is 1.0.

        :return: The opacity of this StampBase.
        :rtype: float
        """
        return self._opacity

    @opacity.setter
    def opacity(self, opacity):
        """
        Sets the opacity of this StampBase.
        Gets or sets a value to indicate the stamp opacity. The value is from 0.0 to 1.0. By default the value is 1.0.

        :param opacity: The opacity of this StampBase.
        :type: float
        """

        self._opacity = opacity

    @property
    def rotate(self):
        """
        Gets the rotate of this StampBase.
        Sets or gets the rotation of stamp content according Rotation values. Note. This property is for set angles which are multiples of 90 degrees (0, 90, 180, 270 degrees). To set arbitrary angle use RotateAngle property.  If angle set by ArbitraryAngle is not multiple of 90 then Rotate property returns Rotation.None.

        :return: The rotate of this StampBase.
        :rtype: Rotation
        """
        return self._rotate

    @rotate.setter
    def rotate(self, rotate):
        """
        Sets the rotate of this StampBase.
        Sets or gets the rotation of stamp content according Rotation values. Note. This property is for set angles which are multiples of 90 degrees (0, 90, 180, 270 degrees). To set arbitrary angle use RotateAngle property.  If angle set by ArbitraryAngle is not multiple of 90 then Rotate property returns Rotation.None.

        :param rotate: The rotate of this StampBase.
        :type: Rotation
        """

        self._rotate = rotate

    @property
    def rotate_angle(self):
        """
        Gets the rotate_angle of this StampBase.
        Gets or sets rotate angle of stamp in degrees. This property allows to set arbitrary rotate angle. 

        :return: The rotate_angle of this StampBase.
        :rtype: float
        """
        return self._rotate_angle

    @rotate_angle.setter
    def rotate_angle(self, rotate_angle):
        """
        Sets the rotate_angle of this StampBase.
        Gets or sets rotate angle of stamp in degrees. This property allows to set arbitrary rotate angle. 

        :param rotate_angle: The rotate_angle of this StampBase.
        :type: float
        """

        self._rotate_angle = rotate_angle

    @property
    def x_indent(self):
        """
        Gets the x_indent of this StampBase.
        Horizontal stamp coordinate, starting from the left.

        :return: The x_indent of this StampBase.
        :rtype: float
        """
        return self._x_indent

    @x_indent.setter
    def x_indent(self, x_indent):
        """
        Sets the x_indent of this StampBase.
        Horizontal stamp coordinate, starting from the left.

        :param x_indent: The x_indent of this StampBase.
        :type: float
        """

        self._x_indent = x_indent

    @property
    def y_indent(self):
        """
        Gets the y_indent of this StampBase.
        Vertical stamp coordinate, starting from the bottom.

        :return: The y_indent of this StampBase.
        :rtype: float
        """
        return self._y_indent

    @y_indent.setter
    def y_indent(self, y_indent):
        """
        Sets the y_indent of this StampBase.
        Vertical stamp coordinate, starting from the bottom.

        :param y_indent: The y_indent of this StampBase.
        :type: float
        """

        self._y_indent = y_indent

    @property
    def zoom(self):
        """
        Gets the zoom of this StampBase.
        Zooming factor of the stamp. Allows to scale stamp.

        :return: The zoom of this StampBase.
        :rtype: float
        """
        return self._zoom

    @zoom.setter
    def zoom(self, zoom):
        """
        Sets the zoom of this StampBase.
        Zooming factor of the stamp. Allows to scale stamp.

        :param zoom: The zoom of this StampBase.
        :type: float
        """

        self._zoom = zoom

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, StampBase):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from configuration import *
file_name = '4pages.pdf'
uploadFile(file_name)
result_file_name = "result.pptx"

opts = {
    "folder": temp_folder
}

response = pdf_api.put_pdf_in_storage_to_pptx(
    file_name, temp_folder + '/' + result_file_name, **opts)

pprint(response)



from configuration import *
file_name = 'PdfWithAnnotations.pdf'
uploadFile(file_name)

parent_id = 'GI5TAOZRGU3CYNZSGEWDCNZWFQ3TGOI'

response = pdf_api.get_document_popup_annotations_by_parent(
    file_name, parent_id, folder=temp_folder)

pprint(response)



from configuration import *
file_name = 'HtmlWithImage.zip'
uploadFile(file_name)

html_file_name = 'HtmlWithImage.html'
opts = {
    "height": 650,
    "width": 250,
    "html_file_name": html_file_name
}
src_path = temp_folder + '/' + file_name
response = pdf_api.get_html_in_storage_to_pdf(src_path, **opts)

pprint(response)


from configuration import *

file_name = 'PdfWithAnnotations1.pdf'
uploadFile(file_name)

attachment_file = '4pages.pdf'
uploadFile(attachment_file)

annotation = asposepdfcloud.models.MovieAnnotation()
annotation.name = 'Test Name'
annotation.rect = asposepdfcloud.models.Rectangle(
    llx=100, lly=100, urx=200, ury=200)
annotation.flags = [asposepdfcloud.models.AnnotationFlags.DEFAULT]
annotation.horizontal_alignment = asposepdfcloud.models.HorizontalAlignment.CENTER
annotation.z_index = 1
annotation.modified = '01/01/2018 12:00:00.000 AM'
annotation.file_path = temp_folder + '/' + attachment_file

response_annotations = pdf_api.get_document_movie_annotations(
    file_name, folder=temp_folder)
annotation_id = response_annotations.annotations.list[0].id

response = pdf_api.put_movie_annotation(
    file_name, annotation_id, annotation, folder=temp_folder)
pprint(response)



from configuration import *
file_name = '4pages.pdf'
result_file_name = "result.mobi"

opts = {
    "file": test_data_path + file_name
}

response = pdf_api.put_pdf_in_request_to_mobi_xml(
    temp_folder + '/' + result_file_name, **opts)

pprint(response)


from configuration import *
file_name = 'PdfWithAnnotations.pdf'
uploadFile(file_name)

page_number = 1

annotation = asposepdfcloud.models.UnderlineAnnotation()
annotation.name = 'Name'
annotation.rect = asposepdfcloud.models.Rectangle(
    llx=100, lly=100, urx=200, ury=200)
annotation.flags = [asposepdfcloud.models.AnnotationFlags.DEFAULT]
annotation.horizontal_alignment = asposepdfcloud.models.HorizontalAlignment.CENTER
annotation.rich_text = 'Rich Text'
annotation.subject = 'Subj'
annotation.z_index = 1
annotation.title = 'Title'
annotation.quad_points = [
    asposepdfcloud.models.Point(10, 10),
    asposepdfcloud.models.Point(20, 10),
    asposepdfcloud.models.Point(10, 20),
    asposepdfcloud.models.Point(10, 10)
]
annotation.modified = '02/02/2018 00:00:00.000 AM'

response = pdf_api.post_page_underline_annotations(
    file_name, page_number,  [annotation], folder=temp_folder)

pprint(response)


# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from pprint import pformat
from six import iteritems
import re


class DocumentConfig(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'display_properties': 'DisplayProperties',
        'document_properties': 'DocumentProperties',
        'pages_count': 'int',
        'default_page_config': 'DefaultPageConfig'
    }

    attribute_map = {
        'display_properties': 'DisplayProperties',
        'document_properties': 'DocumentProperties',
        'pages_count': 'PagesCount',
        'default_page_config': 'DefaultPageConfig'
    }

    def __init__(self, display_properties=None, document_properties=None, pages_count=None, default_page_config=None):
        """
        DocumentConfig - a model defined in Swagger
        """

        self._display_properties = None
        self._document_properties = None
        self._pages_count = None
        self._default_page_config = None

        if display_properties is not None:
          self.display_properties = display_properties
        if document_properties is not None:
          self.document_properties = document_properties
        self.pages_count = pages_count
        if default_page_config is not None:
          self.default_page_config = default_page_config

    @property
    def display_properties(self):
        """
        Gets the display_properties of this DocumentConfig.
        Sets DisplayProperties of document

        :return: The display_properties of this DocumentConfig.
        :rtype: DisplayProperties
        """
        return self._display_properties

    @display_properties.setter
    def display_properties(self, display_properties):
        """
        Sets the display_properties of this DocumentConfig.
        Sets DisplayProperties of document

        :param display_properties: The display_properties of this DocumentConfig.
        :type: DisplayProperties
        """

        self._display_properties = display_properties

    @property
    def document_properties(self):
        """
        Gets the document_properties of this DocumentConfig.
        Sets DocumentProperties of document

        :return: The document_properties of this DocumentConfig.
        :rtype: DocumentProperties
        """
        return self._document_properties

    @document_properties.setter
    def document_properties(self, document_properties):
        """
        Sets the document_properties of this DocumentConfig.
        Sets DocumentProperties of document

        :param document_properties: The document_properties of this DocumentConfig.
        :type: DocumentProperties
        """

        self._document_properties = document_properties

    @property
    def pages_count(self):
        """
        Gets the pages_count of this DocumentConfig.
        Sets count of pages for new document. From 1 to 100

        :return: The pages_count of this DocumentConfig.
        :rtype: int
        """
        return self._pages_count

    @pages_count.setter
    def pages_count(self, pages_count):
        """
        Sets the pages_count of this DocumentConfig.
        Sets count of pages for new document. From 1 to 100

        :param pages_count: The pages_count of this DocumentConfig.
        :type: int
        """
        if pages_count is None:
            raise ValueError("Invalid value for `pages_count`, must not be `None`")

        self._pages_count = pages_count

    @property
    def default_page_config(self):
        """
        Gets the default_page_config of this DocumentConfig.
        Sets default page config for new document

        :return: The default_page_config of this DocumentConfig.
        :rtype: DefaultPageConfig
        """
        return self._default_page_config

    @default_page_config.setter
    def default_page_config(self, default_page_config):
        """
        Sets the default_page_config of this DocumentConfig.
        Sets default page config for new document

        :param default_page_config: The default_page_config of this DocumentConfig.
        :type: DefaultPageConfig
        """

        self._default_page_config = default_page_config

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, DocumentConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from pprint import pformat
from six import iteritems
import re


class FileVersion(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'is_folder': 'bool',
        'modified_date': 'datetime',
        'size': 'int',
        'path': 'str',
        'version_id': 'str',
        'is_latest': 'bool'
    }

    attribute_map = {
        'name': 'Name',
        'is_folder': 'IsFolder',
        'modified_date': 'ModifiedDate',
        'size': 'Size',
        'path': 'Path',
        'version_id': 'VersionId',
        'is_latest': 'IsLatest'
    }

    def __init__(self, name=None, is_folder=None, modified_date=None, size=None, path=None, version_id=None, is_latest=None):
        """
        FileVersion - a model defined in Swagger
        """

        self._name = None
        self._is_folder = None
        self._modified_date = None
        self._size = None
        self._path = None
        self._version_id = None
        self._is_latest = None

        if name is not None:
          self.name = name
        self.is_folder = is_folder
        if modified_date is not None:
          self.modified_date = modified_date
        self.size = size
        if path is not None:
          self.path = path
        if version_id is not None:
          self.version_id = version_id
        self.is_latest = is_latest

    @property
    def name(self):
        """
        Gets the name of this FileVersion.
        File or folder name.

        :return: The name of this FileVersion.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this FileVersion.
        File or folder name.

        :param name: The name of this FileVersion.
        :type: str
        """

        self._name = name

    @property
    def is_folder(self):
        """
        Gets the is_folder of this FileVersion.
        True if it is a folder.

        :return: The is_folder of this FileVersion.
        :rtype: bool
        """
        return self._is_folder

    @is_folder.setter
    def is_folder(self, is_folder):
        """
        Sets the is_folder of this FileVersion.
        True if it is a folder.

        :param is_folder: The is_folder of this FileVersion.
        :type: bool
        """
        if is_folder is None:
            raise ValueError("Invalid value for `is_folder`, must not be `None`")

        self._is_folder = is_folder

    @property
    def modified_date(self):
        """
        Gets the modified_date of this FileVersion.
        File or folder last modified DateTime.

        :return: The modified_date of this FileVersion.
        :rtype: datetime
        """
        return self._modified_date

    @modified_date.setter
    def modified_date(self, modified_date):
        """
        Sets the modified_date of this FileVersion.
        File or folder last modified DateTime.

        :param modified_date: The modified_date of this FileVersion.
        :type: datetime
        """

        self._modified_date = modified_date

    @property
    def size(self):
        """
        Gets the size of this FileVersion.
        File or folder size.

        :return: The size of this FileVersion.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """
        Sets the size of this FileVersion.
        File or folder size.

        :param size: The size of this FileVersion.
        :type: int
        """
        if size is None:
            raise ValueError("Invalid value for `size`, must not be `None`")

        self._size = size

    @property
    def path(self):
        """
        Gets the path of this FileVersion.
        File or folder path.

        :return: The path of this FileVersion.
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this FileVersion.
        File or folder path.

        :param path: The path of this FileVersion.
        :type: str
        """

        self._path = path

    @property
    def version_id(self):
        """
        Gets the version_id of this FileVersion.
        File Version ID.

        :return: The version_id of this FileVersion.
        :rtype: str
        """
        return self._version_id

    @version_id.setter
    def version_id(self, version_id):
        """
        Sets the version_id of this FileVersion.
        File Version ID.

        :param version_id: The version_id of this FileVersion.
        :type: str
        """

        self._version_id = version_id

    @property
    def is_latest(self):
        """
        Gets the is_latest of this FileVersion.
        Specifies whether the file is (true) or is not (false) the latest version of an file.

        :return: The is_latest of this FileVersion.
        :rtype: bool
        """
        return self._is_latest

    @is_latest.setter
    def is_latest(self, is_latest):
        """
        Sets the is_latest of this FileVersion.
        Specifies whether the file is (true) or is not (false) the latest version of an file.

        :param is_latest: The is_latest of this FileVersion.
        :type: bool
        """
        if is_latest is None:
            raise ValueError("Invalid value for `is_latest`, must not be `None`")

        self._is_latest = is_latest

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, FileVersion):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from configuration import *

file_name = 'PdfWithScreenAnnotations.pdf'
uploadFile(file_name)

response = pdf_api.get_document_screen_annotations(
    file_name, folder=temp_folder)


pprint(response)



from configuration import *

file_name = '4pages.pdf'
uploadFile(file_name)

opts = {
    "folder": temp_folder
}

response = pdf_api.get_pdf_in_storage_to_la_te_x(
    file_name, **opts)

pprint(response)


# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from pprint import pformat
from six import iteritems
import re


class ImageFragment(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'image_file': 'str',
        'fix_width': 'float',
        'fix_height': 'float',
        'horizontal_alignment': 'HorizontalAlignment',
        'vertical_alignment': 'VerticalAlignment',
        'image_scale': 'float',
        'margin': 'MarginInfo'
    }

    attribute_map = {
        'image_file': 'ImageFile',
        'fix_width': 'FixWidth',
        'fix_height': 'FixHeight',
        'horizontal_alignment': 'HorizontalAlignment',
        'vertical_alignment': 'VerticalAlignment',
        'image_scale': 'ImageScale',
        'margin': 'Margin'
    }

    def __init__(self, image_file=None, fix_width=None, fix_height=None, horizontal_alignment=None, vertical_alignment=None, image_scale=None, margin=None):
        """
        ImageFragment - a model defined in Swagger
        """

        self._image_file = None
        self._fix_width = None
        self._fix_height = None
        self._horizontal_alignment = None
        self._vertical_alignment = None
        self._image_scale = None
        self._margin = None

        self.image_file = image_file
        if fix_width is not None:
          self.fix_width = fix_width
        if fix_height is not None:
          self.fix_height = fix_height
        if horizontal_alignment is not None:
          self.horizontal_alignment = horizontal_alignment
        if vertical_alignment is not None:
          self.vertical_alignment = vertical_alignment
        if image_scale is not None:
          self.image_scale = image_scale
        if margin is not None:
          self.margin = margin

    @property
    def image_file(self):
        """
        Gets the image_file of this ImageFragment.
        Gets or sets full storage path of image.

        :return: The image_file of this ImageFragment.
        :rtype: str
        """
        return self._image_file

    @image_file.setter
    def image_file(self, image_file):
        """
        Sets the image_file of this ImageFragment.
        Gets or sets full storage path of image.

        :param image_file: The image_file of this ImageFragment.
        :type: str
        """
        if image_file is None:
            raise ValueError("Invalid value for `image_file`, must not be `None`")
        if image_file is not None and len(image_file) < 1:
            raise ValueError("Invalid value for `image_file`, length must be greater than or equal to `1`")

        self._image_file = image_file

    @property
    def fix_width(self):
        """
        Gets the fix_width of this ImageFragment.
        Gets or sets fix width of the image.

        :return: The fix_width of this ImageFragment.
        :rtype: float
        """
        return self._fix_width

    @fix_width.setter
    def fix_width(self, fix_width):
        """
        Sets the fix_width of this ImageFragment.
        Gets or sets fix width of the image.

        :param fix_width: The fix_width of this ImageFragment.
        :type: float
        """

        self._fix_width = fix_width

    @property
    def fix_height(self):
        """
        Gets the fix_height of this ImageFragment.
        Gets or sets fix height of the image.

        :return: The fix_height of this ImageFragment.
        :rtype: float
        """
        return self._fix_height

    @fix_height.setter
    def fix_height(self, fix_height):
        """
        Sets the fix_height of this ImageFragment.
        Gets or sets fix height of the image.

        :param fix_height: The fix_height of this ImageFragment.
        :type: float
        """

        self._fix_height = fix_height

    @property
    def horizontal_alignment(self):
        """
        Gets the horizontal_alignment of this ImageFragment.
        Gets or sets horizontal alignment of the image.

        :return: The horizontal_alignment of this ImageFragment.
        :rtype: HorizontalAlignment
        """
        return self._horizontal_alignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, horizontal_alignment):
        """
        Sets the horizontal_alignment of this ImageFragment.
        Gets or sets horizontal alignment of the image.

        :param horizontal_alignment: The horizontal_alignment of this ImageFragment.
        :type: HorizontalAlignment
        """

        self._horizontal_alignment = horizontal_alignment

    @property
    def vertical_alignment(self):
        """
        Gets the vertical_alignment of this ImageFragment.
        Gets or sets vertical alignment of the image.

        :return: The vertical_alignment of this ImageFragment.
        :rtype: VerticalAlignment
        """
        return self._vertical_alignment

    @vertical_alignment.setter
    def vertical_alignment(self, vertical_alignment):
        """
        Sets the vertical_alignment of this ImageFragment.
        Gets or sets vertical alignment of the image.

        :param vertical_alignment: The vertical_alignment of this ImageFragment.
        :type: VerticalAlignment
        """

        self._vertical_alignment = vertical_alignment

    @property
    def image_scale(self):
        """
        Gets the image_scale of this ImageFragment.
        Gets or sets ImageScale of the image.

        :return: The image_scale of this ImageFragment.
        :rtype: float
        """
        return self._image_scale

    @image_scale.setter
    def image_scale(self, image_scale):
        """
        Sets the image_scale of this ImageFragment.
        Gets or sets ImageScale of the image.

        :param image_scale: The image_scale of this ImageFragment.
        :type: float
        """

        self._image_scale = image_scale

    @property
    def margin(self):
        """
        Gets the margin of this ImageFragment.
        Gets or sets Margin of the image.

        :return: The margin of this ImageFragment.
        :rtype: MarginInfo
        """
        return self._margin

    @margin.setter
    def margin(self, margin):
        """
        Sets the margin of this ImageFragment.
        Gets or sets Margin of the image.

        :param margin: The margin of this ImageFragment.
        :type: MarginInfo
        """

        self._margin = margin

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ImageFragment):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from pprint import pformat
from six import iteritems
import re


class MarkupAnnotation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'links': 'list[Link]',
        'color': 'Color',
        'contents': 'str',
        'modified': 'str',
        'id': 'str',
        'flags': 'list[AnnotationFlags]',
        'name': 'str',
        'rect': 'Rectangle',
        'page_index': 'int',
        'z_index': 'int',
        'horizontal_alignment': 'HorizontalAlignment',
        'vertical_alignment': 'VerticalAlignment',
        'creation_date': 'str',
        'subject': 'str',
        'title': 'str',
        'rich_text': 'str'
    }

    attribute_map = {
        'links': 'Links',
        'color': 'Color',
        'contents': 'Contents',
        'modified': 'Modified',
        'id': 'Id',
        'flags': 'Flags',
        'name': 'Name',
        'rect': 'Rect',
        'page_index': 'PageIndex',
        'z_index': 'ZIndex',
        'horizontal_alignment': 'HorizontalAlignment',
        'vertical_alignment': 'VerticalAlignment',
        'creation_date': 'CreationDate',
        'subject': 'Subject',
        'title': 'Title',
        'rich_text': 'RichText'
    }

    def __init__(self, links=None, color=None, contents=None, modified=None, id=None, flags=None, name=None, rect=None, page_index=None, z_index=None, horizontal_alignment=None, vertical_alignment=None, creation_date=None, subject=None, title=None, rich_text=None):
        """
        MarkupAnnotation - a model defined in Swagger
        """

        self._links = None
        self._color = None
        self._contents = None
        self._modified = None
        self._id = None
        self._flags = None
        self._name = None
        self._rect = None
        self._page_index = None
        self._z_index = None
        self._horizontal_alignment = None
        self._vertical_alignment = None
        self._creation_date = None
        self._subject = None
        self._title = None
        self._rich_text = None

        if links is not None:
          self.links = links
        if color is not None:
          self.color = color
        if contents is not None:
          self.contents = contents
        if modified is not None:
          self.modified = modified
        if id is not None:
          self.id = id
        if flags is not None:
          self.flags = flags
        if name is not None:
          self.name = name
        self.rect = rect
        if page_index is not None:
          self.page_index = page_index
        if z_index is not None:
          self.z_index = z_index
        if horizontal_alignment is not None:
          self.horizontal_alignment = horizontal_alignment
        if vertical_alignment is not None:
          self.vertical_alignment = vertical_alignment
        if creation_date is not None:
          self.creation_date = creation_date
        if subject is not None:
          self.subject = subject
        if title is not None:
          self.title = title
        if rich_text is not None:
          self.rich_text = rich_text

    @property
    def links(self):
        """
        Gets the links of this MarkupAnnotation.
        Link to the document.

        :return: The links of this MarkupAnnotation.
        :rtype: list[Link]
        """
        return self._links

    @links.setter
    def links(self, links):
        """
        Sets the links of this MarkupAnnotation.
        Link to the document.

        :param links: The links of this MarkupAnnotation.
        :type: list[Link]
        """

        self._links = links

    @property
    def color(self):
        """
        Gets the color of this MarkupAnnotation.
        Color of the annotation.

        :return: The color of this MarkupAnnotation.
        :rtype: Color
        """
        return self._color

    @color.setter
    def color(self, color):
        """
        Sets the color of this MarkupAnnotation.
        Color of the annotation.

        :param color: The color of this MarkupAnnotation.
        :type: Color
        """

        self._color = color

    @property
    def contents(self):
        """
        Gets the contents of this MarkupAnnotation.
        Get the annotation content.

        :return: The contents of this MarkupAnnotation.
        :rtype: str
        """
        return self._contents

    @contents.setter
    def contents(self, contents):
        """
        Sets the contents of this MarkupAnnotation.
        Get the annotation content.

        :param contents: The contents of this MarkupAnnotation.
        :type: str
        """

        self._contents = contents

    @property
    def modified(self):
        """
        Gets the modified of this MarkupAnnotation.
        The date and time when the annotation was last modified.

        :return: The modified of this MarkupAnnotation.
        :rtype: str
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """
        Sets the modified of this MarkupAnnotation.
        The date and time when the annotation was last modified.

        :param modified: The modified of this MarkupAnnotation.
        :type: str
        """

        self._modified = modified

    @property
    def id(self):
        """
        Gets the id of this MarkupAnnotation.
        Gets ID of the annotation.

        :return: The id of this MarkupAnnotation.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this MarkupAnnotation.
        Gets ID of the annotation.

        :param id: The id of this MarkupAnnotation.
        :type: str
        """

        self._id = id

    @property
    def flags(self):
        """
        Gets the flags of this MarkupAnnotation.
        Gets Flags of the annotation.

        :return: The flags of this MarkupAnnotation.
        :rtype: list[AnnotationFlags]
        """
        return self._flags

    @flags.setter
    def flags(self, flags):
        """
        Sets the flags of this MarkupAnnotation.
        Gets Flags of the annotation.

        :param flags: The flags of this MarkupAnnotation.
        :type: list[AnnotationFlags]
        """

        self._flags = flags

    @property
    def name(self):
        """
        Gets the name of this MarkupAnnotation.
        Gets Name of the annotation.

        :return: The name of this MarkupAnnotation.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this MarkupAnnotation.
        Gets Name of the annotation.

        :param name: The name of this MarkupAnnotation.
        :type: str
        """

        self._name = name

    @property
    def rect(self):
        """
        Gets the rect of this MarkupAnnotation.
        Gets Rect of the annotation.

        :return: The rect of this MarkupAnnotation.
        :rtype: Rectangle
        """
        return self._rect

    @rect.setter
    def rect(self, rect):
        """
        Sets the rect of this MarkupAnnotation.
        Gets Rect of the annotation.

        :param rect: The rect of this MarkupAnnotation.
        :type: Rectangle
        """
        if rect is None:
            raise ValueError("Invalid value for `rect`, must not be `None`")

        self._rect = rect

    @property
    def page_index(self):
        """
        Gets the page_index of this MarkupAnnotation.
        Gets PageIndex of the annotation.

        :return: The page_index of this MarkupAnnotation.
        :rtype: int
        """
        return self._page_index

    @page_index.setter
    def page_index(self, page_index):
        """
        Sets the page_index of this MarkupAnnotation.
        Gets PageIndex of the annotation.

        :param page_index: The page_index of this MarkupAnnotation.
        :type: int
        """

        self._page_index = page_index

    @property
    def z_index(self):
        """
        Gets the z_index of this MarkupAnnotation.
        Gets ZIndex of the annotation.

        :return: The z_index of this MarkupAnnotation.
        :rtype: int
        """
        return self._z_index

    @z_index.setter
    def z_index(self, z_index):
        """
        Sets the z_index of this MarkupAnnotation.
        Gets ZIndex of the annotation.

        :param z_index: The z_index of this MarkupAnnotation.
        :type: int
        """

        self._z_index = z_index

    @property
    def horizontal_alignment(self):
        """
        Gets the horizontal_alignment of this MarkupAnnotation.
        Gets HorizontalAlignment of the annotation.

        :return: The horizontal_alignment of this MarkupAnnotation.
        :rtype: HorizontalAlignment
        """
        return self._horizontal_alignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, horizontal_alignment):
        """
        Sets the horizontal_alignment of this MarkupAnnotation.
        Gets HorizontalAlignment of the annotation.

        :param horizontal_alignment: The horizontal_alignment of this MarkupAnnotation.
        :type: HorizontalAlignment
        """

        self._horizontal_alignment = horizontal_alignment

    @property
    def vertical_alignment(self):
        """
        Gets the vertical_alignment of this MarkupAnnotation.
        Gets VerticalAlignment of the annotation.

        :return: The vertical_alignment of this MarkupAnnotation.
        :rtype: VerticalAlignment
        """
        return self._vertical_alignment

    @vertical_alignment.setter
    def vertical_alignment(self, vertical_alignment):
        """
        Sets the vertical_alignment of this MarkupAnnotation.
        Gets VerticalAlignment of the annotation.

        :param vertical_alignment: The vertical_alignment of this MarkupAnnotation.
        :type: VerticalAlignment
        """

        self._vertical_alignment = vertical_alignment

    @property
    def creation_date(self):
        """
        Gets the creation_date of this MarkupAnnotation.
        The date and time when the annotation was created.

        :return: The creation_date of this MarkupAnnotation.
        :rtype: str
        """
        return self._creation_date

    @creation_date.setter
    def creation_date(self, creation_date):
        """
        Sets the creation_date of this MarkupAnnotation.
        The date and time when the annotation was created.

        :param creation_date: The creation_date of this MarkupAnnotation.
        :type: str
        """

        self._creation_date = creation_date

    @property
    def subject(self):
        """
        Gets the subject of this MarkupAnnotation.
        Get the annotation subject.

        :return: The subject of this MarkupAnnotation.
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """
        Sets the subject of this MarkupAnnotation.
        Get the annotation subject.

        :param subject: The subject of this MarkupAnnotation.
        :type: str
        """

        self._subject = subject

    @property
    def title(self):
        """
        Gets the title of this MarkupAnnotation.
        Get the annotation title.

        :return: The title of this MarkupAnnotation.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this MarkupAnnotation.
        Get the annotation title.

        :param title: The title of this MarkupAnnotation.
        :type: str
        """

        self._title = title

    @property
    def rich_text(self):
        """
        Gets the rich_text of this MarkupAnnotation.
        Get the annotation RichText.

        :return: The rich_text of this MarkupAnnotation.
        :rtype: str
        """
        return self._rich_text

    @rich_text.setter
    def rich_text(self, rich_text):
        """
        Sets the rich_text of this MarkupAnnotation.
        Get the annotation RichText.

        :param rich_text: The rich_text of this MarkupAnnotation.
        :type: str
        """

        self._rich_text = rich_text

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, MarkupAnnotation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2021 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from pprint import pformat
from six import iteritems
import re


class Signature(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'signature_path': 'str',
        'signature_type': 'SignatureType',
        'password': 'str',
        'appearance': 'str',
        'reason': 'str',
        'contact': 'str',
        'location': 'str',
        'visible': 'bool',
        'rectangle': 'Rectangle',
        'form_field_name': 'str',
        'authority': 'str',
        'date': 'str',
        'show_properties': 'bool',
        'timestamp_settings': 'TimestampSettings',
        'is_valid': 'bool',
        'custom_appearance': 'SignatureCustomAppearance'
    }

    attribute_map = {
        'signature_path': 'SignaturePath',
        'signature_type': 'SignatureType',
        'password': 'Password',
        'appearance': 'Appearance',
        'reason': 'Reason',
        'contact': 'Contact',
        'location': 'Location',
        'visible': 'Visible',
        'rectangle': 'Rectangle',
        'form_field_name': 'FormFieldName',
        'authority': 'Authority',
        'date': 'Date',
        'show_properties': 'ShowProperties',
        'timestamp_settings': 'TimestampSettings',
        'is_valid': 'IsValid',
        'custom_appearance': 'CustomAppearance'
    }

    def __init__(self, signature_path=None, signature_type=None, password=None, appearance=None, reason=None, contact=None, location=None, visible=None, rectangle=None, form_field_name=None, authority=None, date=None, show_properties=None, timestamp_settings=None, is_valid=None, custom_appearance=None):
        """
        Signature - a model defined in Swagger
        """

        self._signature_path = None
        self._signature_type = None
        self._password = None
        self._appearance = None
        self._reason = None
        self._contact = None
        self._location = None
        self._visible = None
        self._rectangle = None
        self._form_field_name = None
        self._authority = None
        self._date = None
        self._show_properties = None
        self._timestamp_settings = None
        self._is_valid = None
        self._custom_appearance = None

        self.signature_path = signature_path
        self.signature_type = signature_type
        if password is not None:
          self.password = password
        if appearance is not None:
          self.appearance = appearance
        if reason is not None:
          self.reason = reason
        if contact is not None:
          self.contact = contact
        if location is not None:
          self.location = location
        self.visible = visible
        if rectangle is not None:
          self.rectangle = rectangle
        if form_field_name is not None:
          self.form_field_name = form_field_name
        if authority is not None:
          self.authority = authority
        if date is not None:
          self.date = date
        self.show_properties = show_properties
        if timestamp_settings is not None:
          self.timestamp_settings = timestamp_settings
        if is_valid is not None:
          self.is_valid = is_valid
        if custom_appearance is not None:
          self.custom_appearance = custom_appearance

    @property
    def signature_path(self):
        """
        Gets the signature_path of this Signature.
        Gets or sets the signature path.

        :return: The signature_path of this Signature.
        :rtype: str
        """
        return self._signature_path

    @signature_path.setter
    def signature_path(self, signature_path):
        """
        Sets the signature_path of this Signature.
        Gets or sets the signature path.

        :param signature_path: The signature_path of this Signature.
        :type: str
        """

        self._signature_path = signature_path

    @property
    def signature_type(self):
        """
        Gets the signature_type of this Signature.
        Gets or sets the type of the signature.

        :return: The signature_type of this Signature.
        :rtype: SignatureType
        """
        return self._signature_type

    @signature_type.setter
    def signature_type(self, signature_type):
        """
        Sets the signature_type of this Signature.
        Gets or sets the type of the signature.

        :param signature_type: The signature_type of this Signature.
        :type: SignatureType
        """
        if signature_type is None:
            raise ValueError("Invalid value for `signature_type`, must not be `None`")

        self._signature_type = signature_type

    @property
    def password(self):
        """
        Gets the password of this Signature.
        Gets or sets the signature password.

        :return: The password of this Signature.
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """
        Sets the password of this Signature.
        Gets or sets the signature password.

        :param password: The password of this Signature.
        :type: str
        """

        self._password = password

    @property
    def appearance(self):
        """
        Gets the appearance of this Signature.
        Sets or gets a graphic appearance for the signature. Property value represents an image file name.

        :return: The appearance of this Signature.
        :rtype: str
        """
        return self._appearance

    @appearance.setter
    def appearance(self, appearance):
        """
        Sets the appearance of this Signature.
        Sets or gets a graphic appearance for the signature. Property value represents an image file name.

        :param appearance: The appearance of this Signature.
        :type: str
        """

        self._appearance = appearance

    @property
    def reason(self):
        """
        Gets the reason of this Signature.
        Gets or sets the reason of the signature.

        :return: The reason of this Signature.
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """
        Sets the reason of this Signature.
        Gets or sets the reason of the signature.

        :param reason: The reason of this Signature.
        :type: str
        """

        self._reason = reason

    @property
    def contact(self):
        """
        Gets the contact of this Signature.
        Gets or sets the contact of the signature.

        :return: The contact of this Signature.
        :rtype: str
        """
        return self._contact

    @contact.setter
    def contact(self, contact):
        """
        Sets the contact of this Signature.
        Gets or sets the contact of the signature.

        :param contact: The contact of this Signature.
        :type: str
        """

        self._contact = contact

    @property
    def location(self):
        """
        Gets the location of this Signature.
        Gets or sets the location of the signature.

        :return: The location of this Signature.
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """
        Sets the location of this Signature.
        Gets or sets the location of the signature.

        :param location: The location of this Signature.
        :type: str
        """

        self._location = location

    @property
    def visible(self):
        """
        Gets the visible of this Signature.
        Gets or sets a value indicating whether this Signature is visible. Supports only when signing particular page.

        :return: The visible of this Signature.
        :rtype: bool
        """
        return self._visible

    @visible.setter
    def visible(self, visible):
        """
        Sets the visible of this Signature.
        Gets or sets a value indicating whether this Signature is visible. Supports only when signing particular page.

        :param visible: The visible of this Signature.
        :type: bool
        """
        if visible is None:
            raise ValueError("Invalid value for `visible`, must not be `None`")

        self._visible = visible

    @property
    def rectangle(self):
        """
        Gets the rectangle of this Signature.
        Gets or sets the visible rectangle of the signature. Supports only when signing particular page.

        :return: The rectangle of this Signature.
        :rtype: Rectangle
        """
        return self._rectangle

    @rectangle.setter
    def rectangle(self, rectangle):
        """
        Sets the rectangle of this Signature.
        Gets or sets the visible rectangle of the signature. Supports only when signing particular page.

        :param rectangle: The rectangle of this Signature.
        :type: Rectangle
        """

        self._rectangle = rectangle

    @property
    def form_field_name(self):
        """
        Gets the form_field_name of this Signature.
        Gets or sets the name of the signature field. Supports only when signing document with particular form field.

        :return: The form_field_name of this Signature.
        :rtype: str
        """
        return self._form_field_name

    @form_field_name.setter
    def form_field_name(self, form_field_name):
        """
        Sets the form_field_name of this Signature.
        Gets or sets the name of the signature field. Supports only when signing document with particular form field.

        :param form_field_name: The form_field_name of this Signature.
        :type: str
        """

        self._form_field_name = form_field_name

    @property
    def authority(self):
        """
        Gets the authority of this Signature.
        Gets or sets the name of the person or authority signing the document..

        :return: The authority of this Signature.
        :rtype: str
        """
        return self._authority

    @authority.setter
    def authority(self, authority):
        """
        Sets the authority of this Signature.
        Gets or sets the name of the person or authority signing the document..

        :param authority: The authority of this Signature.
        :type: str
        """

        self._authority = authority

    @property
    def date(self):
        """
        Gets the date of this Signature.
        Gets or sets the time of signing.

        :return: The date of this Signature.
        :rtype: str
        """
        return self._date

    @date.setter
    def date(self, date):
        """
        Sets the date of this Signature.
        Gets or sets the time of signing.

        :param date: The date of this Signature.
        :type: str
        """

        self._date = date

    @property
    def show_properties(self):
        """
        Gets the show_properties of this Signature.
        Gets or sets the showproperties in signature field

        :return: The show_properties of this Signature.
        :rtype: bool
        """
        return self._show_properties

    @show_properties.setter
    def show_properties(self, show_properties):
        """
        Sets the show_properties of this Signature.
        Gets or sets the showproperties in signature field

        :param show_properties: The show_properties of this Signature.
        :type: bool
        """
        if show_properties is None:
            raise ValueError("Invalid value for `show_properties`, must not be `None`")

        self._show_properties = show_properties

    @property
    def timestamp_settings(self):
        """
        Gets the timestamp_settings of this Signature.
        Gets/sets timestamp settings.

        :return: The timestamp_settings of this Signature.
        :rtype: TimestampSettings
        """
        return self._timestamp_settings

    @timestamp_settings.setter
    def timestamp_settings(self, timestamp_settings):
        """
        Sets the timestamp_settings of this Signature.
        Gets/sets timestamp settings.

        :param timestamp_settings: The timestamp_settings of this Signature.
        :type: TimestampSettings
        """

        self._timestamp_settings = timestamp_settings

    @property
    def is_valid(self):
        """
        Gets the is_valid of this Signature.
        Verify the document regarding this signature and return true if document is valid or otherwise false.

        :return: The is_valid of this Signature.
        :rtype: bool
        """
        return self._is_valid

    @is_valid.setter
    def is_valid(self, is_valid):
        """
        Sets the is_valid of this Signature.
        Verify the document regarding this signature and return true if document is valid or otherwise false.

        :param is_valid: The is_valid of this Signature.
        :type: bool
        """

        self._is_valid = is_valid

    @property
    def custom_appearance(self):
        """
        Gets the custom_appearance of this Signature.
        Gets/sets the custom appearance.

        :return: The custom_appearance of this Signature.
        :rtype: SignatureCustomAppearance
        """
        return self._custom_appearance

    @custom_appearance.setter
    def custom_appearance(self, custom_appearance):
        """
        Sets the custom_appearance of this Signature.
        Gets/sets the custom appearance.

        :param custom_appearance: The custom_appearance of this Signature.
        :type: SignatureCustomAppearance
        """

        self._custom_appearance = custom_appearance

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Signature):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from configuration import *
file_name = 'PdfWithAnnotations.pdf'
uploadFile(file_name)

page_number = 1

annotation = asposepdfcloud.models.RedactionAnnotation()
annotation.name = 'Test Name Updated'
annotation.rect = asposepdfcloud.models.Rectangle(
    llx=100, lly=100, urx=200, ury=200)
annotation.flags = [asposepdfcloud.models.AnnotationFlags.DEFAULT]
annotation.horizontal_alignment = asposepdfcloud.models.HorizontalAlignment.CENTER
annotation.z_index = 1
annotation.quad_point = [
    asposepdfcloud.models.Point(10, 40),
    asposepdfcloud.models.Point(30, 40)
]
annotation.modified = '01/01/2018 12:01:02.000 AM'

response = pdf_api.post_page_redaction_annotations(
    file_name, page_number, [annotation], folder=temp_folder)

response_annotations = pdf_api.get_document_redaction_annotations(
    file_name, folder=temp_folder)
annotation_id = response_annotations.annotations.list[0].id

response = pdf_api.put_redaction_annotation(
    file_name, annotation_id, annotation, folder=temp_folder)
pprint(response)



from configuration import *
file_name = 'XslfoExample.xslfo'
uploadFile(file_name)

src_path = temp_folder + '/' + file_name
response = pdf_api.get_xsl_fo_in_storage_to_pdf(src_path)

pprint(response)
